From 4250cc254bc2bc8ef9f56b22297545053fa3ed81 Mon Sep 17 00:00:00 2001
From: luzpaz
Date: Sat, 2 Dec 2023 11:05:28 +0000
Subject: [PATCH] Fix typos in libs/ subdirectory
---
libs/alignment/AlignmentSubsystemForDrivers.h | 4 ++--
libs/alignment/BasicMathPlugin.cpp | 4 ++--
libs/alignment/BasicMathPlugin.h | 4 ++--
libs/alignment/BuiltInMathPlugin.h | 2 +-
.../ClientAPIForAlignmentDatabase.cpp | 20 +++++++++----------
.../ClientAPIForMathPluginManagement.cpp | 8 ++++----
.../ClientAPIForMathPluginManagement.h | 2 +-
libs/alignment/Common.h | 4 ++--
libs/alignment/InMemoryDatabase.h | 2 +-
.../MapPropertiesToInMemoryDatabase.h | 2 +-
libs/alignment/MathPlugin.h | 4 ++--
libs/alignment/NearestMathPlugin.cpp | 2 +-
libs/alignment/SVDMathPlugin.cpp | 2 +-
libs/alignment/SVDMathPlugin.h | 2 +-
...TelescopeDirectionVectorSupportFunctions.h | 2 +-
libs/alignment/alignment_white_paper.md | 8 ++++----
libs/dsp/dsp.h | 14 ++++++-------
libs/dsp/fits.h | 12 +++++------
libs/dsp/sdfits.h | 4 ++--
libs/fpack/fpackutil.c | 6 +++---
libs/hid/hid_libusb.c | 8 ++++----
libs/hid/hid_mac.c | 6 +++---
libs/hid/hid_win.c | 2 +-
libs/hid/hidtest.cpp | 2 +-
.../indiabstractclient/abstractbaseclient.cpp | 2 +-
libs/indiabstractclient/abstractbaseclient.h | 2 +-
.../connectionplugins/connectioninterface.h | 2 +-
.../connectionplugins/connectiontcp.h | 2 +-
libs/indibase/connectionplugins/ttybase.cpp | 2 +-
libs/indibase/connectionplugins/ttybase.h | 2 +-
libs/indibase/defaultdevice.cpp | 6 +++---
libs/indibase/defaultdevice.h | 10 +++++-----
libs/indibase/indiccd.cpp | 2 +-
libs/indibase/indiccd.h | 10 +++++-----
libs/indibase/indiccdchip.h | 4 ++--
libs/indibase/indicontroller.h | 2 +-
libs/indibase/indicorrelator.h | 2 +-
libs/indibase/indidome.cpp | 4 ++--
libs/indibase/indidome.h | 12 +++++------
libs/indibase/indidriver.c | 2 +-
libs/indibase/indidriver.h | 6 +++---
libs/indibase/indidrivermain.c | 6 +++---
libs/indibase/indidustcapinterface.h | 8 ++++----
libs/indibase/indifilterinterface.h | 6 +++---
libs/indibase/indifocuserinterface.h | 4 ++--
libs/indibase/indigpsinterface.h | 2 +-
libs/indibase/indiguiderinterface.h | 2 +-
libs/indibase/indilightboxinterface.h | 8 ++++----
libs/indibase/indirotator.h | 2 +-
libs/indibase/indirotatorinterface.h | 8 ++++----
libs/indibase/indisensorinterface.h | 6 +++---
libs/indibase/inditelescope.cpp | 4 ++--
libs/indibase/inditelescope.h | 10 +++++-----
libs/indibase/indiweather.h | 2 +-
libs/indibase/indiweatherinterface.h | 4 ++--
libs/indibase/stream/ccvt.h | 2 +-
libs/indibase/stream/ccvt_misc.c | 2 +-
libs/indibase/stream/jpegutils.c | 4 ++--
libs/indibase/stream/jpegutils.h | 2 +-
libs/indibase/stream/recorder/serrecorder.cpp | 2 +-
.../stream/recorder/theorarecorder.cpp | 2 +-
libs/indibase/stream/streammanager.cpp | 2 +-
libs/indibase/stream/streammanager_p.h | 2 +-
libs/indibase/webcam/pwc-ioctl.h | 2 +-
libs/indibase/webcam/v4l2_base.cpp | 4 ++--
.../v4l2_decode/v4l2_builtin_decoder.cpp | 4 ++--
libs/indiclient/baseclient.cpp | 2 +-
libs/indiclient/baseclient.h | 2 +-
libs/indiclientqt/baseclientqt.cpp | 2 +-
libs/indiclientqt/baseclientqt.h | 2 +-
libs/indicore/base64.h | 2 +-
libs/indicore/indiapi.h.in | 10 +++++-----
libs/indicore/indicom.c | 2 +-
libs/indicore/indicom.h | 18 ++++++++---------
libs/indicore/indidevapi.h | 6 +++---
libs/indicore/lilxml.cpp | 8 ++++----
libs/indicore/lilxml.h | 8 ++++----
libs/indidevice/basedevice.h | 8 ++++----
libs/indidevice/basedevice_p.h | 2 +-
libs/indidevice/indibase.h | 4 ++--
libs/indidevice/indistandardproperty.h | 4 ++--
libs/inicpp.h | 4 ++--
libs/json.h | 4 ++--
83 files changed, 193 insertions(+), 193 deletions(-)
diff --git a/libs/alignment/AlignmentSubsystemForDrivers.h b/libs/alignment/AlignmentSubsystemForDrivers.h
index d0fc378a3f..aba10e6c7b 100644
--- a/libs/alignment/AlignmentSubsystemForDrivers.h
+++ b/libs/alignment/AlignmentSubsystemForDrivers.h
@@ -36,7 +36,7 @@ class AlignmentSubsystemForDrivers : public MapPropertiesToInMemoryDatabase,
/// \brief Virtual destructor
virtual ~AlignmentSubsystemForDrivers() {}
- /** \brief Initilize alignment subsystem properties. It is recommended to call this function within initProperties() of your primary device
+ /** \brief Initialize alignment subsystem properties. It is recommended to call this function within initProperties() of your primary device
* \param[in] pTelescope Pointer to the child INDI::Telecope class
*/
void InitAlignmentProperties(Telescope *pTelescope);
@@ -173,7 +173,7 @@ class AlignmentSubsystemForDrivers : public MapPropertiesToInMemoryDatabase,
* the in memory database module. This registration is performed in the constructor of
* of this class. The callback is called whenever the database is
* is loaded or reloaded, by default it calls the Initialise function of the MathPluginManagment module.
- * \param[in] ThisPointer Pointer to the instance of this class which registered the callbck
+ * \param[in] ThisPointer Pointer to the instance of this class which registered the callback
*/
static void MyDatabaseLoadCallback(void *ThisPointer);
};
diff --git a/libs/alignment/BasicMathPlugin.cpp b/libs/alignment/BasicMathPlugin.cpp
index 144ce6033d..b2e2ed952f 100644
--- a/libs/alignment/BasicMathPlugin.cpp
+++ b/libs/alignment/BasicMathPlugin.cpp
@@ -464,7 +464,7 @@ bool BasicMathPlugin::TransformCelestialToTelescope(const double RightAscension,
#ifdef CONVEX_HULL_DEBUGGING
ActualFaces++;
#endif
- // Ignore faces containg vertex 0 (nadir).
+ // Ignore faces containing vertex 0 (nadir).
if ((0 == CurrentFace->vertex[0]->vnum) || (0 == CurrentFace->vertex[1]->vnum) ||
(0 == CurrentFace->vertex[2]->vnum))
{
@@ -695,7 +695,7 @@ bool BasicMathPlugin::TransformTelescopeToCelestial(const TelescopeDirectionVect
#ifdef CONVEX_HULL_DEBUGGING
ApparentFaces++;
#endif
- // Ignore faces containg vertex 0 (nadir).
+ // Ignore faces containing vertex 0 (nadir).
if ((0 == CurrentFace->vertex[0]->vnum) || (0 == CurrentFace->vertex[1]->vnum) ||
(0 == CurrentFace->vertex[2]->vnum))
{
diff --git a/libs/alignment/BasicMathPlugin.h b/libs/alignment/BasicMathPlugin.h
index e09e630725..50d8309a89 100644
--- a/libs/alignment/BasicMathPlugin.h
+++ b/libs/alignment/BasicMathPlugin.h
@@ -42,7 +42,7 @@ class BasicMathPlugin : public AlignmentSubsystemForMathPlugins
double &RightAscension, double &Declination);
protected:
- /// \brief Calculate tranformation matrices from the supplied vectors
+ /// \brief Calculate transformation matrices from the supplied vectors
/// \param[in] Alpha1 Pointer to the first coordinate in the alpha reference frame
/// \param[in] Alpha2 Pointer to the second coordinate in the alpha reference frame
/// \param[in] Alpha3 Pointer to the third coordinate in the alpha reference frame
@@ -67,7 +67,7 @@ class BasicMathPlugin : public AlignmentSubsystemForMathPlugins
/// \param[in] pMatrix The matrix to print
void Dump3x3(const char *Label, gsl_matrix *pMatrix);
- /// \brief Caluclate the determinant of the supplied matrix
+ /// \brief Calculate the determinant of the supplied matrix
/// \param[in] pMatrix Pointer to the 3x3 matrix
/// \return The determinant
double Matrix3x3Determinant(gsl_matrix *pMatrix);
diff --git a/libs/alignment/BuiltInMathPlugin.h b/libs/alignment/BuiltInMathPlugin.h
index def53391db..4f660e3805 100644
--- a/libs/alignment/BuiltInMathPlugin.h
+++ b/libs/alignment/BuiltInMathPlugin.h
@@ -20,7 +20,7 @@ namespace AlignmentSubsystem
class BuiltInMathPlugin : public BasicMathPlugin
{
private:
- /// \brief Calculate tranformation matrices from the supplied vectors
+ /// \brief Calculate transformation matrices from the supplied vectors
/// \param[in] Alpha1 Pointer to the first coordinate in the alpha reference frame
/// \param[in] Alpha2 Pointer to the second coordinate in the alpha reference frame
/// \param[in] Alpha3 Pointer to the third coordinate in the alpha reference frame
diff --git a/libs/alignment/ClientAPIForAlignmentDatabase.cpp b/libs/alignment/ClientAPIForAlignmentDatabase.cpp
index 8da9c1def9..dff037865c 100644
--- a/libs/alignment/ClientAPIForAlignmentDatabase.cpp
+++ b/libs/alignment/ClientAPIForAlignmentDatabase.cpp
@@ -28,7 +28,7 @@ ClientAPIForAlignmentDatabase::~ClientAPIForAlignmentDatabase()
bool ClientAPIForAlignmentDatabase::AppendSyncPoint(const AlignmentDatabaseEntry &CurrentValues)
{
- // Wait for driver to initialise if neccessary
+ // Wait for driver to initialise if necessary
WaitForDriverCompletion();
auto pAction = Action->getSwitch();
@@ -69,7 +69,7 @@ bool ClientAPIForAlignmentDatabase::AppendSyncPoint(const AlignmentDatabaseEntry
bool ClientAPIForAlignmentDatabase::ClearSyncPoints()
{
- // Wait for driver to initialise if neccessary
+ // Wait for driver to initialise if necessary
WaitForDriverCompletion();
auto pAction = Action->getSwitch();
@@ -107,7 +107,7 @@ bool ClientAPIForAlignmentDatabase::ClearSyncPoints()
bool ClientAPIForAlignmentDatabase::DeleteSyncPoint(unsigned int Offset)
{
- // Wait for driver to initialise if neccessary
+ // Wait for driver to initialise if necessary
WaitForDriverCompletion();
auto pAction = Action->getSwitch();
@@ -158,7 +158,7 @@ bool ClientAPIForAlignmentDatabase::DeleteSyncPoint(unsigned int Offset)
bool ClientAPIForAlignmentDatabase::EditSyncPoint(unsigned int Offset, const AlignmentDatabaseEntry &CurrentValues)
{
- // Wait for driver to initialise if neccessary
+ // Wait for driver to initialise if necessary
WaitForDriverCompletion();
auto pAction = Action->getSwitch();
@@ -222,7 +222,7 @@ void ClientAPIForAlignmentDatabase::Initialise(INDI::BaseClient *BaseClient)
bool ClientAPIForAlignmentDatabase::InsertSyncPoint(unsigned int Offset, const AlignmentDatabaseEntry &CurrentValues)
{
- // Wait for driver to initialise if neccessary
+ // Wait for driver to initialise if necessary
WaitForDriverCompletion();
auto pAction = Action->getSwitch();
@@ -276,7 +276,7 @@ bool ClientAPIForAlignmentDatabase::InsertSyncPoint(unsigned int Offset, const A
bool ClientAPIForAlignmentDatabase::LoadDatabase()
{
- // Wait for driver to initialise if neccessary
+ // Wait for driver to initialise if necessary
WaitForDriverCompletion();
auto pAction = Action->getSwitch();
@@ -379,7 +379,7 @@ void ClientAPIForAlignmentDatabase::ProcessNewProperty(INDI::Property *PropertyP
else
GotOneOfMine = false;
- // Tell the client when all the database proeprties have been set up
+ // Tell the client when all the database properties have been set up
if (GotOneOfMine && (nullptr != MandatoryNumbers) && (nullptr != OptionalBinaryBlob) && (nullptr != PointsetSize) &&
(nullptr != CurrentEntry) && (nullptr != Action) && (nullptr != Commit))
{
@@ -406,7 +406,7 @@ void ClientAPIForAlignmentDatabase::ProcessNewSwitch(ISwitchVectorProperty *Swit
bool ClientAPIForAlignmentDatabase::ReadIncrementSyncPoint(AlignmentDatabaseEntry &CurrentValues)
{
- // Wait for driver to initialise if neccessary
+ // Wait for driver to initialise if necessary
WaitForDriverCompletion();
auto pAction = Action->getSwitch();
@@ -458,7 +458,7 @@ bool ClientAPIForAlignmentDatabase::ReadIncrementSyncPoint(AlignmentDatabaseEntr
bool ClientAPIForAlignmentDatabase::ReadSyncPoint(unsigned int Offset, AlignmentDatabaseEntry &CurrentValues)
{
- // Wait for driver to initialise if neccessary
+ // Wait for driver to initialise if necessary
WaitForDriverCompletion();
auto pAction = Action->getSwitch();
@@ -520,7 +520,7 @@ bool ClientAPIForAlignmentDatabase::ReadSyncPoint(unsigned int Offset, Alignment
bool ClientAPIForAlignmentDatabase::SaveDatabase()
{
- // Wait for driver to initialise if neccessary
+ // Wait for driver to initialise if necessary
WaitForDriverCompletion();
auto pAction = Action->getSwitch();
diff --git a/libs/alignment/ClientAPIForMathPluginManagement.cpp b/libs/alignment/ClientAPIForMathPluginManagement.cpp
index 84d0365512..96c4dfccfd 100644
--- a/libs/alignment/ClientAPIForMathPluginManagement.cpp
+++ b/libs/alignment/ClientAPIForMathPluginManagement.cpp
@@ -18,7 +18,7 @@ namespace AlignmentSubsystem
bool ClientAPIForMathPluginManagement::EnumerateMathPlugins(MathPluginsList &AvailableMathPlugins)
{
- // Wait for driver to initialise if neccessary
+ // Wait for driver to initialise if necessary
WaitForDriverCompletion();
AvailableMathPlugins.clear();
@@ -52,7 +52,7 @@ void ClientAPIForMathPluginManagement::ProcessNewProperty(INDI::Property *Proper
else
GotOneOfMine = false;
- // Tell the client when all the database proeprties have been set up
+ // Tell the client when all the database properties have been set up
if (GotOneOfMine && (nullptr != MathPlugins) && (nullptr != PluginInitialise))
{
// The DriverActionComplete state variable is initialised to false
@@ -78,7 +78,7 @@ void ClientAPIForMathPluginManagement::ProcessNewSwitch(ISwitchVectorProperty *S
bool ClientAPIForMathPluginManagement::SelectMathPlugin(const std::string &MathPluginName)
{
- // Wait for driver to initialise if neccessary
+ // Wait for driver to initialise if necessary
WaitForDriverCompletion();
auto pPlugins = MathPlugins->getSwitch();
@@ -107,7 +107,7 @@ bool ClientAPIForMathPluginManagement::SelectMathPlugin(const std::string &MathP
bool ClientAPIForMathPluginManagement::ReInitialiseMathPlugin()
{
- // Wait for driver to initialise if neccessary
+ // Wait for driver to initialise if necessary
WaitForDriverCompletion();
auto pPluginInitialise = PluginInitialise->getSwitch();
diff --git a/libs/alignment/ClientAPIForMathPluginManagement.h b/libs/alignment/ClientAPIForMathPluginManagement.h
index 482b300c72..9e0b6a2f9b 100644
--- a/libs/alignment/ClientAPIForMathPluginManagement.h
+++ b/libs/alignment/ClientAPIForMathPluginManagement.h
@@ -41,7 +41,7 @@ class ClientAPIForMathPluginManagement
*/
bool EnumerateMathPlugins(MathPluginsList &AvailableMathPlugins);
- /// \brief Intialise the API
+ /// \brief Initialise the API
/// \param[in] BaseClient Pointer to the INDI:BaseClient class
void Initialise(INDI::BaseClient *BaseClient);
diff --git a/libs/alignment/Common.h b/libs/alignment/Common.h
index 15ab778676..9a193f3947 100644
--- a/libs/alignment/Common.h
+++ b/libs/alignment/Common.h
@@ -25,7 +25,7 @@ namespace AlignmentSubsystem
{
/** \enum MountAlignment
\brief Describe the alignment of a telescope axis. This is normally used to differentiate between
- equatorial mounts in differnet hemispheres and altaz or dobsonian mounts.
+ equatorial mounts in different hemispheres and altaz or dobsonian mounts.
*/
typedef enum MountAlignment { ZENITH, NORTH_CELESTIAL_POLE, SOUTH_CELESTIAL_POLE } MountAlignment_t;
@@ -59,7 +59,7 @@ enum AlignmentPointSetEnum
/*!
* \struct TelescopeDirectionVector
- * \brief Holds a nomalised direction vector (direction cosines)
+ * \brief Holds a normalised direction vector (direction cosines)
*
* The x y,z fields of this class should normally represent a normalised (unit length)
* vector in a right handed rectangular coordinate space. However, for convenience a number
diff --git a/libs/alignment/InMemoryDatabase.h b/libs/alignment/InMemoryDatabase.h
index ddd3025e97..953ad7f5d1 100644
--- a/libs/alignment/InMemoryDatabase.h
+++ b/libs/alignment/InMemoryDatabase.h
@@ -52,7 +52,7 @@ class InMemoryDatabase
}
/// \brief Get the database reference position
- /// \param[in] Position A pointer to a IGeographicCoordinates object to retunr the current position in
+ /// \param[in] Position A pointer to a IGeographicCoordinates object to return the current position in
/// \return True if successful
bool GetDatabaseReferencePosition(IGeographicCoordinates &Position);
diff --git a/libs/alignment/MapPropertiesToInMemoryDatabase.h b/libs/alignment/MapPropertiesToInMemoryDatabase.h
index 74f9b161f9..6f1eec8715 100644
--- a/libs/alignment/MapPropertiesToInMemoryDatabase.h
+++ b/libs/alignment/MapPropertiesToInMemoryDatabase.h
@@ -59,7 +59,7 @@ namespace AlignmentSubsystem
* - READ INCREMENT\n
* Increment the pointer before reading the entry.
* - LOAD DATABASE\n
- * Load the databse from local storage.
+ * Load the database from local storage.
* - SAVE DATABASE\n
* Save the database to local storage.
* - ALIGNMENT_POINTSET_COMMIT\n
diff --git a/libs/alignment/MathPlugin.h b/libs/alignment/MathPlugin.h
index fc5076a552..35b1e000ce 100644
--- a/libs/alignment/MathPlugin.h
+++ b/libs/alignment/MathPlugin.h
@@ -39,7 +39,7 @@ class MathPlugin
virtual ~MathPlugin() {}
// Public methods
- /// \brief Get the approximate alognment of the mount
+ /// \brief Get the approximate alignment of the mount
/// \return the approximate alignment
virtual MountAlignment_t GetApproximateMountAlignment()
{
@@ -50,7 +50,7 @@ class MathPlugin
/// \return True if successful
virtual bool Initialise(InMemoryDatabase *pInMemoryDatabase);
- /// \brief Set the approximate alognment of the mount
+ /// \brief Set the approximate alignment of the mount
/// \param[in] ApproximateAlignment - the approximate alignment of the mount
virtual void SetApproximateMountAlignment(MountAlignment_t ApproximateAlignment)
{
diff --git a/libs/alignment/NearestMathPlugin.cpp b/libs/alignment/NearestMathPlugin.cpp
index 0f101e060a..b4c2886d49 100644
--- a/libs/alignment/NearestMathPlugin.cpp
+++ b/libs/alignment/NearestMathPlugin.cpp
@@ -87,7 +87,7 @@ bool NearestMathPlugin::Initialise(InMemoryDatabase *pInMemoryDatabase)
// JM: We iterate over all the sync point and compute the celestial and telescope horizontal coordinates
// Since these are used to sort the nearest alignment points to the current target. The offsets of the
- // nearest point celestial coordintes are then applied to the current target to correct for its position.
+ // nearest point celestial coordinates are then applied to the current target to correct for its position.
// No complex transformations used.
for (auto &oneSyncPoint : SyncPoints)
{
diff --git a/libs/alignment/SVDMathPlugin.cpp b/libs/alignment/SVDMathPlugin.cpp
index 72feabe15c..f96976b094 100644
--- a/libs/alignment/SVDMathPlugin.cpp
+++ b/libs/alignment/SVDMathPlugin.cpp
@@ -72,7 +72,7 @@ void SVDMathPlugin::CalculateTransformMatrices(const TelescopeDirectionVector &A
gsl_matrix *pIntermediateMatrix1 = gsl_matrix_alloc(3, 3);
MatrixMatrixMultiply(pBetaMatrix, pAlphaMatrix, pIntermediateMatrix1);
- // 3. Compute the singular value decomoposition of the intermediate matrix
+ // 3. Compute the singular value decomposition of the intermediate matrix
gsl_matrix *pV = gsl_matrix_alloc(3, 3);
gsl_vector *pS = gsl_vector_alloc(3);
gsl_vector *pWork = gsl_vector_alloc(3);
diff --git a/libs/alignment/SVDMathPlugin.h b/libs/alignment/SVDMathPlugin.h
index c298e52887..bc9a56299a 100644
--- a/libs/alignment/SVDMathPlugin.h
+++ b/libs/alignment/SVDMathPlugin.h
@@ -20,7 +20,7 @@ namespace AlignmentSubsystem
class SVDMathPlugin : public BasicMathPlugin
{
private:
- /// \brief Calculate tranformation matrices from the supplied vectors
+ /// \brief Calculate transformation matrices from the supplied vectors
/// \param[in] Alpha1 Pointer to the first coordinate in the alpha reference frame
/// \param[in] Alpha2 Pointer to the second coordinate in the alpha reference frame
/// \param[in] Alpha3 Pointer to the third coordinate in the alpha reference frame
diff --git a/libs/alignment/TelescopeDirectionVectorSupportFunctions.h b/libs/alignment/TelescopeDirectionVectorSupportFunctions.h
index 7a7652739c..40251dfe8d 100644
--- a/libs/alignment/TelescopeDirectionVectorSupportFunctions.h
+++ b/libs/alignment/TelescopeDirectionVectorSupportFunctions.h
@@ -19,7 +19,7 @@ namespace AlignmentSubsystem
/*! \class TelescopeDirectionVectorSupportFunctions
* \brief These functions are used to convert different coordinate systems to and from the
* telescope direction vectors (normalised vector/direction cosines) used for telescope coordinates in the
- * alignment susbsystem.
+ * alignment subsystem.
*/
class TelescopeDirectionVectorSupportFunctions
{
diff --git a/libs/alignment/alignment_white_paper.md b/libs/alignment/alignment_white_paper.md
index 190867a9ad..25387fe583 100644
--- a/libs/alignment/alignment_white_paper.md
+++ b/libs/alignment/alignment_white_paper.md
@@ -418,7 +418,7 @@ The final step is to add coordinate conversion to ReadScopeStatus, TimerHit (for
{
if (AzimuthOffsetMicrosteps < MICROSTEPS_PER_REVOLUTION / 2.0)
{
- // Foward
+ // Forward
AxisDirectionRA = FORWARD;
AxisSlewRateRA = AzimuthOffsetMicrosteps;
}
@@ -434,7 +434,7 @@ The final step is to add coordinate conversion to ReadScopeStatus, TimerHit (for
AzimuthOffsetMicrosteps = abs(AzimuthOffsetMicrosteps);
if (AzimuthOffsetMicrosteps < MICROSTEPS_PER_REVOLUTION / 2.0)
{
- // Foward
+ // Forward
AxisDirectionRA = REVERSE;
AxisSlewRateRA = AzimuthOffsetMicrosteps;
}
@@ -615,7 +615,7 @@ The Alignment Subsystem provides two API classes for use in clients. These are C
class LoaderClient : public INDI::BaseClient, INDI::AlignmentSubsystem::AlignmentSubsystemForClients
-Somewhere in the initialisation of your client make a call to the Initalise method of the AlignmentSubsystemForClients class for example:
+Somewhere in the initialisation of your client make a call to the Initialise method of the AlignmentSubsystemForClients class for example:
void LoaderClient::Initialise(int argc, char* argv[])
{
@@ -643,7 +643,7 @@ Somewhere in the initialisation of your client make a call to the Initalise meth
setBLOBMode(B_ALSO, DeviceName.c_str(), NULL);
}
-To hook the Alignment Subsystem into the clients property handling you must ensure that the following virtual functions are overriden.
+To hook the Alignment Subsystem into the clients property handling you must ensure that the following virtual functions are overridden.
virtual void newBLOB(IBLOB *bp);
virtual void newDevice(INDI::BaseDevice *dp);
diff --git a/libs/dsp/dsp.h b/libs/dsp/dsp.h
index bc8c98c8c4..2854dc29d6 100644
--- a/libs/dsp/dsp.h
+++ b/libs/dsp/dsp.h
@@ -58,8 +58,8 @@ extern "C" {
* The DSP API is a collection of essential routines used in astronomy signal processing
*
* The DSP API is used for processing monodimensional or multidimensional buffers,
-* generating, tranforming, stack, processing buffers, aligning, convoluting arrays,
-* converting array element types, generate statistics, extract informations from buffers, convolute or
+* generating, transforming, stack, processing buffers, aligning, convoluting arrays,
+* converting array element types, generate statistics, extract information from buffers, convolute or
* cross-correlate different single or multi dimensional streams, rotate, scale, crop images.
*
* \author Ilia Platone
@@ -280,7 +280,7 @@ typedef struct dsp_triangle_t
} dsp_triangle;
/**
-* \brief Alignment informations needed
+* \brief Alignment information needed
*/
typedef struct dsp_align_info_t
{
@@ -366,7 +366,7 @@ typedef union dsp_location_t
typedef void *(*dsp_func_t) (void *, ...);
/**
-* \brief Contains a set of informations and data relative to a buffer and how to use it
+* \brief Contains a set of information and data relative to a buffer and how to use it
* \sa dsp_stream_new
* \sa dsp_stream_add_dim
* \sa dsp_stream_del_dim
@@ -469,7 +469,7 @@ DLL_EXPORT void dsp_fourier_idft(dsp_stream_p stream);
DLL_EXPORT void dsp_fourier_2dsp(dsp_stream_p stream);
/**
-* \brief Obtain the complex fourier tranform from the current magnitude and phase buffers
+* \brief Obtain the complex fourier transform from the current magnitude and phase buffers
* \param stream the inout stream.
*/
DLL_EXPORT void dsp_fourier_2complex_t(dsp_stream_p stream);
@@ -774,7 +774,7 @@ DLL_EXPORT void dsp_convolution_correlation(dsp_stream_p stream, dsp_stream_p ma
* \brief Histogram of the inut stream
* \param stream the stream on which execute
* \param size the length of the median.
-* \return the output stream if successfull elaboration. NULL if an
+* \return the output stream if successful elaboration. NULL if an
* error is encountered.
*/
DLL_EXPORT double* dsp_stats_histogram(dsp_stream_p stream, int size);
@@ -1532,7 +1532,7 @@ DLL_EXPORT dsp_t* dsp_file_composite_2_bayer(dsp_stream_p *src, int red, int wid
DLL_EXPORT void dsp_file_write_fits_bayer(const char* filename, int components, int bpp, dsp_stream_p* stream);
/**
-* \brief Convert a bayer pattern dsp_t array into a contiguos component array
+* \brief Convert a bayer pattern dsp_t array into a contiguous component array
* \param src the input buffer
* \param red the location of the red pixel within the bayer pattern
* \param width the picture width
diff --git a/libs/dsp/fits.h b/libs/dsp/fits.h
index a5108da671..386e01f290 100644
--- a/libs/dsp/fits.h
+++ b/libs/dsp/fits.h
@@ -243,7 +243,7 @@ DLL_EXPORT long dsp_fits_alloc_fits_rows(fitsfile *fptr, unsigned long num_rows)
* \param typecode The element type size
* \param num_elements The total field size in elements, this should take into account the width and repeat multipliers
* \param rown The row number where the field is located
-* \return non-zero if any error occured
+* \return non-zero if any error occurred
* \sa dsp_fits_create_fits
*/
DLL_EXPORT int dsp_fits_fill_fits_col(fitsfile *fptr, char* name, unsigned char *buf, int typecode, long num_elements,
@@ -254,7 +254,7 @@ DLL_EXPORT int dsp_fits_fill_fits_col(fitsfile *fptr, char* name, unsigned char
* \param fptr The fits file pointer created by dsp_fits_create_fits
* \param name The name of the column
* \param format This field should indicate the element size, width of each element and repetition eventually
-* \return non-zero if any error occured
+* \return non-zero if any error occurred
*/
DLL_EXPORT int dsp_fits_append_fits_col(fitsfile *fptr, char* name, char* format);
@@ -278,7 +278,7 @@ DLL_EXPORT size_t dsp_fits_get_element_size(int typecode);
* \param typecode This function will return the typecode to this variable
* \param width This function will return the width to this variable
* \param repeat This function will return the repeatition count to this variable
-* \return non-zero if any error occured
+* \return non-zero if any error occurred
*/
DLL_EXPORT int dsp_fits_read_typecode(char* typestr, int *typecode, long *width, long *repeat);
@@ -288,7 +288,7 @@ DLL_EXPORT int dsp_fits_read_typecode(char* typestr, int *typecode, long *width,
* \param column The column name of the selected field
* \param rown The row position of the field
* \param retval A preallocated buffer where the field value will be stored into
-* \return non-zero if any error occured
+* \return non-zero if any error occurred
*/
DLL_EXPORT int dsp_fits_get_value(fitsfile *fptr, char* column, long rown, void **retval);
@@ -316,14 +316,14 @@ DLL_EXPORT fitsfile* dsp_fits_create_fits(size_t *size, void **buf);
* \param columns An array of dsp_fits_column structs
* \param ncols The dsp_fits_column array length
* \param tablename The extension table name
-* \return non-zero if any error occured
+* \return non-zero if any error occurred
*/
DLL_EXPORT int dsp_fits_add_table(fitsfile* fptr, dsp_fits_column *columns, int ncols, const char* tablename);
/**
* \brief Close a fits file pointer
* \param fptr The fits file pointer created by dsp_fits_create_fits
-* \return non-zero if any error occured
+* \return non-zero if any error occurred
*/
DLL_EXPORT int dsp_fits_close_fits(fitsfile *fptr);
/**\}*/
diff --git a/libs/dsp/sdfits.h b/libs/dsp/sdfits.h
index c76214c9ec..ca78485f88 100644
--- a/libs/dsp/sdfits.h
+++ b/libs/dsp/sdfits.h
@@ -194,8 +194,8 @@ extern "C" {
#define SDFITS_COLUMN_WINDDIRE (dsp_fits_column){"WINDDIRE", EXTFITS_ELEMENT_DOUBLE.typestr, EXTFITS_MEASURE_UNIT_DEGREE, "", "Degrees West of North", (char*[]){""}}
///Main-beam efficiency
#define SDFITS_COLUMN_BEAMEFF (dsp_fits_column){"BEAMEFF", EXTFITS_ELEMENT_DOUBLE.typestr, EXTFITS_MEASURE_UNIT_PERCENT, "", "Main-beam efficiency", (char*[]){""}}
-///Antenna Aperature Efficiency
-#define SDFITS_COLUMN_APEREFF (dsp_fits_column){"APEREFF", EXTFITS_ELEMENT_DOUBLE.typestr, EXTFITS_MEASURE_UNIT_PERCENT, "", "Antenna Aperature Efficiency", (char*[]){""}}
+///Antenna Aperture Efficiency
+#define SDFITS_COLUMN_APEREFF (dsp_fits_column){"APEREFF", EXTFITS_ELEMENT_DOUBLE.typestr, EXTFITS_MEASURE_UNIT_PERCENT, "", "Antenna Aperture Efficiency", (char*[]){""}}
///Rear spillover
#define SDFITS_COLUMN_ETAL (dsp_fits_column){"ETAL", EXTFITS_ELEMENT_DOUBLE.typestr, "", "", "Rear spillover", (char*[]){""}}
///Accounts for forward loss
diff --git a/libs/fpack/fpackutil.c b/libs/fpack/fpackutil.c
index 98ba89c4ee..f84cf31d89 100644
--- a/libs/fpack/fpackutil.c
+++ b/libs/fpack/fpackutil.c
@@ -398,7 +398,7 @@ int fp_preflight (int argc, char *argv[], int unpack, fpstate *fpptr)
/* check that input file exists */
if (infits[0] != '-') { /* if not reading from stdin stream */
if (fp_access (infits) != 0) { /* if not, then check if */
- strcat(infits, ".fz"); /* a .fz version exsits */
+ strcat(infits, ".fz"); /* a .fz version exists */
if (fp_access (infits) != 0) {
namelen = strlen(infits);
infits[namelen - 3] = '\0'; /* remove the .fz suffix */
@@ -511,7 +511,7 @@ int fp_preflight (int argc, char *argv[], int unpack, fpstate *fpptr)
fp_msg ("Error: input file name too long:\n "); fp_msg (infits);
fp_msg ("\n "); fp_noop (); exit (-1);
}
- strcat(infits, ".gz"); /* a gzipped version exsits */
+ strcat(infits, ".gz"); /* a gzipped version exists */
if (fp_access (infits) != 0) {
namelen = strlen(infits);
infits[namelen - 3] = '\0'; /* remove the .gz suffix */
@@ -632,7 +632,7 @@ int fp_loop (int argc, char *argv[], int unpack, char *output_filename, fpstate
/* find input file */
if (infits[0] != '-') { /* if not reading from stdin stream */
if (fp_access (infits) != 0) { /* if not, then */
- strcat(infits, ".fz"); /* a .fz version must exsit */
+ strcat(infits, ".fz"); /* a .fz version must exist */
}
}
diff --git a/libs/hid/hid_libusb.c b/libs/hid/hid_libusb.c
index bf54c69a7d..2ee85e8f92 100644
--- a/libs/hid/hid_libusb.c
+++ b/libs/hid/hid_libusb.c
@@ -152,7 +152,7 @@ static void free_hid_device(hid_device *dev)
}
#if 0
-//TODO: Implement this funciton on hidapi/libusb..
+//TODO: Implement this function on hidapi/libusb..
static void register_error(hid_device * device, const char * op)
{
@@ -770,7 +770,7 @@ static void *read_thread(void *param)
/* Now that the read thread is stopping, Wake any threads which are
waiting on data (in hid_read_timeout()). Do this under a mutex to
make sure that a thread which is about to go to sleep waiting on
- the condition acutally will go to sleep before the condition is
+ the condition actually will go to sleep before the condition is
signaled. */
pthread_mutex_lock(&dev->mutex);
pthread_cond_broadcast(&dev->condition);
@@ -885,7 +885,7 @@ hid_device *HID_API_EXPORT hid_open_path(const char *path)
int is_output = (ep->bEndpointAddress & LIBUSB_ENDPOINT_DIR_MASK) == LIBUSB_ENDPOINT_OUT;
int is_input = (ep->bEndpointAddress & LIBUSB_ENDPOINT_DIR_MASK) == LIBUSB_ENDPOINT_IN;
- /* Decide whether to use it for intput or output. */
+ /* Decide whether to use it for input or output. */
if (dev->input_endpoint == 0 && is_interrupt && is_input)
{
/* Use this endpoint for INPUT */
@@ -941,7 +941,7 @@ int HID_API_EXPORT hid_write(hid_device *dev, const unsigned char *data, size_t
if (dev->output_endpoint <= 0)
{
- /* No interrput out endpoint. Use the Control Endpoint */
+ /* No interrupt out endpoint. Use the Control Endpoint */
res = libusb_control_transfer(dev->device_handle,
LIBUSB_REQUEST_TYPE_CLASS | LIBUSB_RECIPIENT_INTERFACE | LIBUSB_ENDPOINT_OUT,
0x09 /*HID Set_Report*/, (2 /*HID output*/ << 8) | report_number, dev->interface,
diff --git a/libs/hid/hid_mac.c b/libs/hid/hid_mac.c
index d30a44bde3..e752334ce1 100644
--- a/libs/hid/hid_mac.c
+++ b/libs/hid/hid_mac.c
@@ -671,7 +671,7 @@ static void *read_thread(void *param)
/* Now that the read thread is stopping, Wake any threads which are
waiting on data (in hid_read_timeout()). Do this under a mutex to
make sure that a thread which is about to go to sleep waiting on
- the condition acutally will go to sleep before the condition is
+ the condition actually will go to sleep before the condition is
signaled. */
pthread_mutex_lock(&dev->mutex);
pthread_cond_broadcast(&dev->condition);
@@ -829,7 +829,7 @@ static int cond_wait(const hid_device *dev, pthread_cond_t *cond, pthread_mutex_
return res;
/* A res of 0 means we may have been signaled or it may
- be a spurious wakeup. Check to see that there's acutally
+ be a spurious wakeup. Check to see that there's actually
data in the queue before returning, and if not, go back
to sleep. See the pthread_cond_timedwait() man page for
details. */
@@ -851,7 +851,7 @@ static int cond_timedwait(const hid_device *dev, pthread_cond_t *cond, pthread_m
return res;
/* A res of 0 means we may have been signaled or it may
- be a spurious wakeup. Check to see that there's acutally
+ be a spurious wakeup. Check to see that there's actually
data in the queue before returning, and if not, go back
to sleep. See the pthread_cond_timedwait() man page for
details. */
diff --git a/libs/hid/hid_win.c b/libs/hid/hid_win.c
index 25fa6a466f..0d214444c5 100644
--- a/libs/hid/hid_win.c
+++ b/libs/hid/hid_win.c
@@ -154,7 +154,7 @@ static hid_device *new_hid_device()
dev->read_pending = FALSE;
dev->read_buf = NULL;
memset(&dev->ol, 0, sizeof(dev->ol));
- dev->ol.hEvent = CreateEvent(NULL, FALSE, FALSE /*inital state f=nonsignaled*/, NULL);
+ dev->ol.hEvent = CreateEvent(NULL, FALSE, FALSE /*initial state f=nonsignaled*/, NULL);
return dev;
}
diff --git a/libs/hid/hidtest.cpp b/libs/hid/hidtest.cpp
index 4b2b6fbe35..fe110329aa 100644
--- a/libs/hid/hidtest.cpp
+++ b/libs/hid/hidtest.cpp
@@ -112,7 +112,7 @@ int main(int argc, char* argv[])
// Set the hid_read() function to be non-blocking.
hid_set_nonblocking(handle, 1);
- // Try to read from the device. There shoud be no
+ // Try to read from the device. There should be no
// data here, but execution should not block.
res = hid_read(handle, buf, 17);
diff --git a/libs/indiabstractclient/abstractbaseclient.cpp b/libs/indiabstractclient/abstractbaseclient.cpp
index f8699a7b0d..004c65cef2 100644
--- a/libs/indiabstractclient/abstractbaseclient.cpp
+++ b/libs/indiabstractclient/abstractbaseclient.cpp
@@ -32,7 +32,7 @@
#if defined(_MSC_VER)
#define snprintf _snprintf
#pragma warning(push)
-///@todo Introduce plattform indipendent safe functions as macros to fix this
+///@todo Introduce platform independent safe functions as macros to fix this
#pragma warning(disable : 4996)
#endif
diff --git a/libs/indiabstractclient/abstractbaseclient.h b/libs/indiabstractclient/abstractbaseclient.h
index 3f03ed1fe7..1ce8a72a73 100644
--- a/libs/indiabstractclient/abstractbaseclient.h
+++ b/libs/indiabstractclient/abstractbaseclient.h
@@ -58,7 +58,7 @@ class AbstractBaseClient : public INDI::BaseMediator
public:
/** @brief Connect to INDI server.
* @returns True if the connection is successful, false otherwise.
- * @note This function blocks until connection is either successull or unsuccessful.
+ * @note This function blocks until connection is either successfull or unsuccessful.
*/
virtual bool connectServer() = 0;
diff --git a/libs/indibase/connectionplugins/connectioninterface.h b/libs/indibase/connectionplugins/connectioninterface.h
index 31bac80a5f..27f0112609 100644
--- a/libs/indibase/connectionplugins/connectioninterface.h
+++ b/libs/indibase/connectionplugins/connectioninterface.h
@@ -115,7 +115,7 @@ class Interface
virtual bool saveConfigItems(FILE *fp);
/**
- * @brief registerHandshake Register a handshake function to be called once the intial connection to the device is established.
+ * @brief registerHandshake Register a handshake function to be called once the initial connection to the device is established.
* @param callback Handshake function callback
* @see INDI::Telescope
*/
diff --git a/libs/indibase/connectionplugins/connectiontcp.h b/libs/indibase/connectionplugins/connectiontcp.h
index ad4e7d08c1..321e2d7525 100644
--- a/libs/indibase/connectionplugins/connectiontcp.h
+++ b/libs/indibase/connectionplugins/connectiontcp.h
@@ -30,7 +30,7 @@ namespace Connection
{
/**
* @brief The TCP class manages connection with devices over the network via TCP/IP.
- * Upon successfull connection, reads & writes from and to the device are performed via the returned file descriptor
+ * Upon successful connection, reads & writes from and to the device are performed via the returned file descriptor
* using standard UNIX read/write functions.
*/
diff --git a/libs/indibase/connectionplugins/ttybase.cpp b/libs/indibase/connectionplugins/ttybase.cpp
index b57ceadfc4..e6247782bd 100644
--- a/libs/indibase/connectionplugins/ttybase.cpp
+++ b/libs/indibase/connectionplugins/ttybase.cpp
@@ -66,7 +66,7 @@
#if defined(_MSC_VER)
#define snprintf _snprintf
#pragma warning(push)
-///@todo Introduce plattform indipendent safe functions as macros to fix this
+///@todo Introduce platform independent safe functions as macros to fix this
#pragma warning(disable : 4996)
#endif
diff --git a/libs/indibase/connectionplugins/ttybase.h b/libs/indibase/connectionplugins/ttybase.h
index 654fee8e21..28fe36a6fb 100644
--- a/libs/indibase/connectionplugins/ttybase.h
+++ b/libs/indibase/connectionplugins/ttybase.h
@@ -70,7 +70,7 @@ class TTYBase
/** \brief read buffer from terminal with a delimiter
\param fd file descriptor
- \param buf pointer to store data. Must be initilized and big enough to hold data.
+ \param buf pointer to store data. Must be initialized and big enough to hold data.
\param stop_char if the function encounters \e stop_char then it stops reading and returns the buffer.
\param nsize size of buf. If stop character is not encountered before nsize, the function aborts.
\param timeout number of seconds to wait for terminal before a timeout error is issued.
diff --git a/libs/indibase/defaultdevice.cpp b/libs/indibase/defaultdevice.cpp
index d4bedea041..6b723e0d09 100644
--- a/libs/indibase/defaultdevice.cpp
+++ b/libs/indibase/defaultdevice.cpp
@@ -451,7 +451,7 @@ bool DefaultDevice::loadDefaultConfig()
if (pResult)
LOG_INFO("Default configuration loaded.");
else
- LOGF_INFO("Error loading default configuraiton. %s", errmsg);
+ LOGF_INFO("Error loading default configuration. %s", errmsg);
return pResult;
}
@@ -806,7 +806,7 @@ int DefaultDevice::SetTimer(uint32_t ms)
}
// Remove main timer. ID is not used.
-// Kept for backward compatiblity
+// Kept for backward compatibility
void DefaultDevice::RemoveTimer(int id)
{
INDI_UNUSED(id);
@@ -816,7 +816,7 @@ void DefaultDevice::RemoveTimer(int id)
}
// This is just a placeholder
-// This function should be overriden by child classes if they use timers
+// This function should be overridden by child classes if they use timers
// So we should never get here
void DefaultDevice::TimerHit()
{
diff --git a/libs/indibase/defaultdevice.h b/libs/indibase/defaultdevice.h
index 753eca83df..138f3cb6cf 100644
--- a/libs/indibase/defaultdevice.h
+++ b/libs/indibase/defaultdevice.h
@@ -204,7 +204,7 @@ class DefaultDevice : public ParentDevice
* @brief deleteProperty Delete a property and unregister it. It will also be deleted from all clients.
* @param property Property to be deleted.
* @return True if successful, false otherwise.
- * @note This is a convience function that internally calls deleteProperty with the property name.
+ * @note This is a convenience function that internally calls deleteProperty with the property name.
*/
bool deleteProperty(INDI::Property &property);
@@ -316,7 +316,7 @@ class DefaultDevice : public ParentDevice
* You may send an ORed list of DeviceInterface values.
* @param value ORed list of DeviceInterface values.
* @warning This only updates the internal driver interface property and does not send it to the
- * client. To synchronize the client, use syncDriverInfo funciton.
+ * client. To synchronize the client, use syncDriverInfo function.
*/
void setDriverInterface(uint16_t value);
@@ -329,7 +329,7 @@ class DefaultDevice : public ParentDevice
protected:
/**
- * @brief setDynamicPropertiesBehavior controls handling of dynamic properties. Dyanmic properties
+ * @brief setDynamicPropertiesBehavior controls handling of dynamic properties. Dynamic properties
* are those generated from an external skeleton XML file. By default all properties, including
* dynamic properties, are defined to the client in ISGetProperties(). Furthermore, when
* űdeleteProperty(properyName) is called, the dynamic property is deleted by default, and can only
@@ -451,8 +451,8 @@ class DefaultDevice : public ParentDevice
bool isSimulation() const;
/**
- * \brief Initilize properties initial state and value. The child class must implement this function.
- * \return True if initilization is successful, false otherwise.
+ * \brief Initialize properties initial state and value. The child class must implement this function.
+ * \return True if initialization is successful, false otherwise.
*/
virtual bool initProperties();
diff --git a/libs/indibase/indiccd.cpp b/libs/indibase/indiccd.cpp
index 6e837b1636..83b3e073a4 100644
--- a/libs/indibase/indiccd.cpp
+++ b/libs/indibase/indiccd.cpp
@@ -991,7 +991,7 @@ bool CCD::ISNewText(const char * dev, const char * name, char * texts[], char *
else
{
FITSHeaderTP.setState(IPS_OK);
- // Specical keyword
+ // Special keyword
if (name == "INDI_CLEAR")
{
m_CustomFITSKeywords.clear();
diff --git a/libs/indibase/indiccd.h b/libs/indibase/indiccd.h
index 56dc86c721..a257d8be42 100644
--- a/libs/indibase/indiccd.h
+++ b/libs/indibase/indiccd.h
@@ -91,7 +91,7 @@ class XISFWrapper;
* It requires the client to explicitly support websockets. It is not recommended to use this
* approach unless for the most demanding and FPS sensitive tasks.
*
- * INDI::CCD and INDI::StreamManager both upload frames asynchrounously in a worker thread.
+ * INDI::CCD and INDI::StreamManager both upload frames asynchronously in a worker thread.
* The CCD Buffer data is protected by the ccdBufferLock mutex. When reading the camera data
* and writing to the buffer, it must be first locked by the mutex. After the write is complete
* release the lock. For example:
@@ -103,7 +103,7 @@ class XISFWrapper;
* ExposureComplete();
* \endcode
*
- * Similiary, before calling Streamer->newFrame, the buffer needs to be protected in a similiar fashion using
+ * Similarly, before calling Streamer->newFrame, the buffer needs to be protected in a similar fashion using
* the same ccdBufferLock mutex.
*
* \example CCD Simulator
@@ -305,7 +305,7 @@ class CCD : public DefaultDevice, GuiderInterface
virtual bool StartExposure(float duration);
/**
- * \brief Uploads target Chip exposed buffer as FITS to the client. Dervied classes should class
+ * \brief Uploads target Chip exposed buffer as FITS to the client. Derived classes should class
* this function when an exposure is complete.
* @param targetChip chip that contains upload image data
* \note This function is not implemented in CCD, it must be implemented in the child class
@@ -414,7 +414,7 @@ class CCD : public DefaultDevice, GuiderInterface
virtual bool UpdateGuiderFrameType(CCDChip::CCD_FRAME fType);
/**
- * \brief Setup CCD paramters for primary CCD. Child classes call this function to update
+ * \brief Setup CCD parameters for primary CCD. Child classes call this function to update
* CCD parameters
* \param x Frame X coordinates in pixels.
* \param y Frame Y coordinates in pixels.
@@ -425,7 +425,7 @@ class CCD : public DefaultDevice, GuiderInterface
virtual void SetCCDParams(int x, int y, int bpp, float xf, float yf);
/**
- * \brief Setup CCD paramters for guide head CCD. Child classes call this function to update
+ * \brief Setup CCD parameters for guide head CCD. Child classes call this function to update
* CCD parameters
* \param x Frame X coordinates in pixels.
* \param y Frame Y coordinates in pixels.
diff --git a/libs/indibase/indiccdchip.h b/libs/indibase/indiccdchip.h
index 13cd248dce..6f8e199fc7 100644
--- a/libs/indibase/indiccdchip.h
+++ b/libs/indibase/indiccdchip.h
@@ -304,7 +304,7 @@ class CCDChip
/**
* @brief setPixelSize Set CCD Chip pixel size
- * @param x Horziontal pixel size in microns.
+ * @param x Horizontal pixel size in microns.
* @param y Vertical pixel size in microns.
*/
void setPixelSize(double x, double y);
@@ -380,7 +380,7 @@ class CCDChip
void setNAxis(int value);
/**
- * @brief setImageExtension Set image exntension
+ * @brief setImageExtension Set image extension
* @param ext extension (fits, jpeg, raw..etc)
*/
void setImageExtension(const char *ext);
diff --git a/libs/indibase/indicontroller.h b/libs/indibase/indicontroller.h
index 1b177edf78..1326a7dff0 100644
--- a/libs/indibase/indicontroller.h
+++ b/libs/indibase/indicontroller.h
@@ -47,7 +47,7 @@ namespace INDI
* ISNewXXX functions from the same standard functions in your driver.
*
* The class communicates with INDI joystick driver which in turn enumerates the game pad and provides
- * three types of constrcuts:
+ * three types of constructs:
*
* - Joysticks: Each joystick displays a normalized magnitude [0 to 1] and an angle. The angle is measured counter clock wise starting from
* the right/east direction [0 to 360]. They are defined as JOYSTICK_# where # is the joystick number.
diff --git a/libs/indibase/indicorrelator.h b/libs/indibase/indicorrelator.h
index b2ebec0c56..c46ee01b12 100644
--- a/libs/indibase/indicorrelator.h
+++ b/libs/indibase/indicorrelator.h
@@ -93,7 +93,7 @@ class Correlator : public SensorInterface
/**
* \enum Correlation
- * \brief Struct containing the correlation, coordinate and baseline informations.
+ * \brief Struct containing the correlation, coordinate and baseline information.
*/
typedef struct
{
diff --git a/libs/indibase/indidome.cpp b/libs/indibase/indidome.cpp
index 2356da0108..0915466dfd 100644
--- a/libs/indibase/indidome.cpp
+++ b/libs/indibase/indidome.cpp
@@ -3,7 +3,7 @@
Copyright(c) 2014 Jasem Mutlaq. All rights reserved.
The code used calculate dome target AZ and ZD is written by Ferran Casarramona, and adapted from code from Markus Wildi.
- The transformations are based on the paper Matrix Method for Coodinates Transformation written by Toshimi Taki (http://www.asahi-net.or.jp/~zs3t-tk).
+ The transformations are based on the paper Matrix Method for Coordinates Transformation written by Toshimi Taki (http://www.asahi-net.or.jp/~zs3t-tk).
This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Library General Public
@@ -1305,7 +1305,7 @@ bool Dome::GetTargetAz(double &Az, double &Alt, double &minAz, double &maxAz)
{
if(OTASideS[DM_OTA_SIDE_HA].s == ISS_ON || (UseHourAngle && OTASideS[DM_OTA_SIDE_MOUNT].s == ISS_ON))
{
- // Note if the telescope points West, OTA is at east of the pier, and viceversa.
+ // Note if the telescope points West, OTA is at east of the pier, and vice-versa.
if(hourAngle > 0)
OTASide = -1;
else
diff --git a/libs/indibase/indidome.h b/libs/indibase/indidome.h
index 0290ca3203..c04d784103 100644
--- a/libs/indibase/indidome.h
+++ b/libs/indibase/indidome.h
@@ -3,7 +3,7 @@
Copyright(c) 2014 Jasem Mutlaq. All rights reserved.
The code used calculate dome target AZ and ZD is written by Ferran Casarramona, and adapted from code from Markus Wildi.
- The transformations are based on the paper Matrix Method for Coodinates Transformation written by Toshimi Taki (http://www.asahi-net.or.jp/~zs3t-tk).
+ The transformations are based on the paper Matrix Method for Coordinates Transformation written by Toshimi Taki (http://www.asahi-net.or.jp/~zs3t-tk).
This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Library General Public
@@ -63,7 +63,7 @@ class TCP;
Developers need to subclass INDI::Dome to implement any driver for Domes within INDI.
- \note The code used calculate dome target AZ and ZD is written by Ferran Casarramona, and adapted from code from Markus Wildi. The transformations are based on the paper Matrix Method for Coodinates
+ \note The code used calculate dome target AZ and ZD is written by Ferran Casarramona, and adapted from code from Markus Wildi. The transformations are based on the paper Matrix Method for Coordinates
Transformation written by Toshimi Taki (http://www.asahi-net.or.jp/~zs3t-tk).
\author Jasem Mutlaq
@@ -155,7 +155,7 @@ class Dome : public DefaultDevice
{
DOME_CAN_ABORT = 1 << 0, /*!< Can the dome motion be aborted? */
DOME_CAN_ABS_MOVE = 1 << 1, /*!< Can the dome move to an absolute azimuth position? */
- DOME_CAN_REL_MOVE = 1 << 2, /*!< Can the dome move to a relative position a number of degrees away from current position? Positive degress is Clockwise direction. Negative Degrees is counter clock wise direction */
+ DOME_CAN_REL_MOVE = 1 << 2, /*!< Can the dome move to a relative position a number of degrees away from current position? Positive degrees is Clockwise direction. Negative Degrees is counter clock wise direction */
DOME_CAN_PARK = 1 << 3, /*!< Can the dome park and unpark itself? */
DOME_CAN_SYNC = 1 << 4, /*!< Can the dome sync to arbitrary position? */
DOME_HAS_SHUTTER = 1 << 5, /*!< Does the dome has a shutter than can be opened and closed electronically? */
@@ -420,13 +420,13 @@ class Dome : public DefaultDevice
/**
* @brief SetRAPark Set current AZ parking position. The data park file (stored in ~/.indi/ParkData.xml) is updated in the process.
- * @param value current Axis 1 value (AZ either in angles or encoder values as specificed by the DomeParkData type).
+ * @param value current Axis 1 value (AZ either in angles or encoder values as specified by the DomeParkData type).
*/
void SetAxis1Park(double value);
/**
* @brief SetAxis1Park Set default AZ parking position.
- * @param value Default Axis 1 value (AZ either in angles or encoder values as specificed by the DomeParkData type).
+ * @param value Default Axis 1 value (AZ either in angles or encoder values as specified by the DomeParkData type).
*/
void SetAxis1ParkDefault(double steps);
@@ -603,7 +603,7 @@ class Dome : public DefaultDevice
ISwitchVectorProperty DomeAutoSyncSP;
ISwitch DomeAutoSyncS[2];
- // Backlash toogle
+ // Backlash toggle
ISwitchVectorProperty DomeBacklashSP;
ISwitch DomeBacklashS[2];
diff --git a/libs/indibase/indidriver.c b/libs/indibase/indidriver.c
index 12801c7e3f..3270318035 100644
--- a/libs/indibase/indidriver.c
+++ b/libs/indibase/indidriver.c
@@ -294,7 +294,7 @@ int dispatch(XMLEle *root, char msg[])
}
}
- /* check tag in surmised decreasing order of likelyhood */
+ /* check tag in surmised decreasing order of likelihood */
if (!strcmp(rtag, "newNumberVector"))
{
diff --git a/libs/indibase/indidriver.h b/libs/indibase/indidriver.h
index c582326295..3c73548c6f 100644
--- a/libs/indibase/indidriver.h
+++ b/libs/indibase/indidriver.h
@@ -41,7 +41,7 @@ extern int dispatch(XMLEle *root, char msg[]);
//extern void clientMsgCB(int fd, void *arg);
/**
- * @defgroup configFunctions Configuration Functions: Functions drivers call to save and load configuraion options.
+ * @defgroup configFunctions Configuration Functions: Functions drivers call to save and load configuration options.
*
* Drivers can save properties states and values in an XML configuration file. The following functions take an optional filename
* parameter which specifies the full path of the configuration file. If the filename is set to NULL, the configuration file
@@ -57,7 +57,7 @@ extern int dispatch(XMLEle *root, char msg[]);
*
*
If no filename is supplied, each function will try to create the configuration files in the following order:
*
- * - INDICONFIG environment variable: The functions checks if the envrionment variable is defined, and if so, it shall
+ *
- INDICONFIG environment variable: The functions checks if the environment variable is defined, and if so, it shall
* be used as the configuration filename
* - Generate filename: If the device_name is supplied, the function will attempt to set the configuration filename to ~/.indi/device_name_config.xml
*
@@ -120,7 +120,7 @@ extern int IUSaveDefaultConfig(const char *source_config, const char *dest_confi
/** @brief Add opening or closing tag to a configuration file.
* A configuration file root XML element is \. This functions add \ or \ as required.
* @param fp file pointer to a configuration file.
- * @param ctag If 0, \ is appened to the configuration file, otherwise \ is appeneded and the fp is closed.
+ * @param ctag If 0, \ is appended to the configuration file, otherwise \ is appended and the fp is closed.
* @param dev device name. Used only for sending notification to the driver if silent is set to 1.
* @param silent If silent is 1, it will suppress any output messages to the driver.
*/
diff --git a/libs/indibase/indidrivermain.c b/libs/indibase/indidrivermain.c
index 20e3b00e7e..366c589508 100644
--- a/libs/indibase/indidrivermain.c
+++ b/libs/indibase/indidrivermain.c
@@ -65,8 +65,8 @@ static int messageHandling = PROCEED_IMMEDIATE;
/* callback when INDI client message arrives on stdin.
- * collect and dispatch when see outter element closure.
- * exit if OS trouble or see incompatable INDI version.
+ * collect and dispatch when see outer element closure.
+ * exit if OS trouble or see incompatible INDI version.
* arg is not used.
*/
static void clientMsgCB(int fd, void *arg)
@@ -122,7 +122,7 @@ typedef struct DeferredMessage
struct DeferredMessage * prev;
} DeferredMessage;
-// Messages will accumulate here until beeing processed
+// Messages will accumulate here until being processed
static DeferredMessage * firstDeferredMessage = NULL;
static DeferredMessage * lastDeferredMessage = NULL;
diff --git a/libs/indibase/indifocuserinterface.h b/libs/indibase/indifocuserinterface.h
index 1775ed6166..1dfd2483d4 100644
--- a/libs/indibase/indifocuserinterface.h
+++ b/libs/indibase/indifocuserinterface.h
@@ -158,7 +158,7 @@ class FocuserInterface
virtual ~FocuserInterface() = default;
/**
- * \brief Initilize focuser properties. It is recommended to call this function within
+ * \brief Initialize focuser properties. It is recommended to call this function within
* initProperties() of your primary device
* \param groupName Group or tab name to be used to define focuser properties.
*/
@@ -302,7 +302,7 @@ class FocuserInterface
ISwitchVectorProperty FocusReverseSP;
ISwitch FocusReverseS[2];
- // Backlash toogle
+ // Backlash toggle
ISwitchVectorProperty FocusBacklashSP;
ISwitch FocusBacklashS[2];
diff --git a/libs/indibase/indigpsinterface.h b/libs/indibase/indigpsinterface.h
index 0bc24e18af..bc8fa19bee 100644
--- a/libs/indibase/indigpsinterface.h
+++ b/libs/indibase/indigpsinterface.h
@@ -55,7 +55,7 @@ class GPSInterface
virtual ~GPSInterface() = default;
/**
- * \brief Initilize focuser properties. It is recommended to call this function within
+ * \brief Initialize focuser properties. It is recommended to call this function within
* initProperties() of your primary device
* \param groupName Group or tab name to be used to define focuser properties.
*/
diff --git a/libs/indibase/indiguiderinterface.h b/libs/indibase/indiguiderinterface.h
index 0747641eae..04402d1af6 100644
--- a/libs/indibase/indiguiderinterface.h
+++ b/libs/indibase/indiguiderinterface.h
@@ -90,7 +90,7 @@ class GuiderInterface
~GuiderInterface();
/**
- * @brief Initilize guider properties. It is recommended to call this function within
+ * @brief Initialize guider properties. It is recommended to call this function within
* initProperties() of your primary device
* @param deviceName Name of the primary device
* @param groupName Group or tab name to be used to define guider properties.
diff --git a/libs/indibase/indirotator.h b/libs/indibase/indirotator.h
index 624305c97e..774b909e95 100644
--- a/libs/indibase/indirotator.h
+++ b/libs/indibase/indirotator.h
@@ -32,7 +32,7 @@ class TCP;
Rotators must be able to move to a specific angle. Other capabilities including abort, syncing, homing are optional.
- The angle is to be interpreted as the raw angle and not necessairly the position angle as this definition should be
+ The angle is to be interpreted as the raw angle and not necessarily the position angle as this definition should be
handled by clients after homing and syncing.
This class is designed for pure rotator devices. To utilize Rotator Interface in another type of device, inherit from RotatorInterface.
diff --git a/libs/indibase/indisensorinterface.h b/libs/indibase/indisensorinterface.h
index 948f6c1982..ce969b2c41 100644
--- a/libs/indibase/indisensorinterface.h
+++ b/libs/indibase/indisensorinterface.h
@@ -233,7 +233,7 @@ class SensorInterface : public DefaultDevice
void setNAxis(int value);
/**
- * @brief setIntegrationExtension Set integration exntension
+ * @brief setIntegrationExtension Set integration extension
* @param ext extension (fits, jpeg, raw..etc)
*/
void setIntegrationFileExtension(const char *ext);
@@ -293,7 +293,7 @@ class SensorInterface : public DefaultDevice
virtual bool StartIntegration(double duration);
/**
- * \brief Uploads target Device exposed buffer as FITS to the client. Dervied classes should class
+ * \brief Uploads target Device exposed buffer as FITS to the client. Derived classes should class
* this function when an Integration is complete.
* @param targetDevice device that contains upload integration data
* \note This function is not implemented in Sensor, it must be implemented in the child class
@@ -322,7 +322,7 @@ class SensorInterface : public DefaultDevice
* \brief Add FITS keywords to a fits file
* \param fptr pointer to a valid FITS file.
* \param buf The buffer of the fits contents.
- * \param len The lenght of the buffer.
+ * \param len The length of the buffer.
* \note In additional to the standard FITS keywords, this function write the following
* keywords the FITS file:
*
diff --git a/libs/indibase/inditelescope.cpp b/libs/indibase/inditelescope.cpp
index ab1be9dded..456c7c4fb5 100644
--- a/libs/indibase/inditelescope.cpp
+++ b/libs/indibase/inditelescope.cpp
@@ -911,7 +911,7 @@ bool Telescope::ISNewNumber(const char *dev, const char *name, double values[],
if (TrackState == SCOPE_TRACKING && !strcmp(IUFindOnSwitch(&TrackModeSP)->name, "TRACK_CUSTOM"))
{
- // Check that we do not abruplty change positive tracking rates to negative ones.
+ // Check that we do not abruptly change positive tracking rates to negative ones.
// tracking must be stopped first.
// Give warning is tracking sign would cause a reverse in direction
if ( (preAxis1 * TrackRateN[AXIS_RA].value < 0) || (preAxis2 * TrackRateN[AXIS_DE].value < 0) )
@@ -1268,7 +1268,7 @@ bool Telescope::ISNewSwitch(const char *dev, const char *name, ISState *states,
//if (TrackState != SCOPE_PARKED)
//TrackState = SCOPE_IDLE;
// For Idle, Tracking, Parked state, we do not change its status, it should remain as is.
- // For Slewing & Parking, state should go back to last rememberd state.
+ // For Slewing & Parking, state should go back to last remembered state.
if (TrackState == SCOPE_SLEWING || TrackState == SCOPE_PARKING)
{
TrackState = RememberTrackState;
diff --git a/libs/indibase/inditelescope.h b/libs/indibase/inditelescope.h
index 10c3ac1ea8..64371e4378 100644
--- a/libs/indibase/inditelescope.h
+++ b/libs/indibase/inditelescope.h
@@ -369,7 +369,7 @@ class Telescope : public DefaultDevice
double GetAxis2Park() const;
/**
- * @return Get defailt DEC/ALT parking position.
+ * @return Get default DEC/ALT parking position.
*/
double GetAxis2ParkDefault() const;
@@ -453,7 +453,7 @@ class Telescope : public DefaultDevice
* - Update telescope status: Idle, Slewing, Parking..etc.
* - Read coordinates
*
- * \return True if reading scope status is OK, false if an error is encounterd.
+ * \return True if reading scope status is OK, false if an error is encountered.
* \note This function is not implemented in Telescope, it must be implemented in the
* child class
*/
@@ -716,7 +716,7 @@ class Telescope : public DefaultDevice
ISwitchVectorProperty CoordSP;
ISwitch CoordS[4];
- // A number vector that stores lattitude and longitude
+ // A number vector that stores latitude and longitude
INumberVectorProperty LocationNP;
INumber LocationN[3];
@@ -772,7 +772,7 @@ class Telescope : public DefaultDevice
ISwitchVectorProperty DomePolicySP;
ISwitch DomePolicyS[2];
- // Switch for choosing between motion control by 4-way joystick or two seperate axes
+ // Switch for choosing between motion control by 4-way joystick or two separate axes
ISwitchVectorProperty MotionControlModeTP;
ISwitch MotionControlModeT[2];
enum
@@ -781,7 +781,7 @@ class Telescope : public DefaultDevice
MOTION_CONTROL_AXES
};
- // Lock Joystick Axis to one direciton only
+ // Lock Joystick Axis to one direction only
ISwitch LockAxisS[2];
ISwitchVectorProperty LockAxisSP;
diff --git a/libs/indibase/indiweather.h b/libs/indibase/indiweather.h
index 103b8fea4d..844631c63d 100644
--- a/libs/indibase/indiweather.h
+++ b/libs/indibase/indiweather.h
@@ -122,7 +122,7 @@ class Weather : public DefaultDevice, public WeatherInterface
/** \brief perform handshake with device to check communication */
virtual bool Handshake();
- // A number vector that stores lattitude and longitude
+ // A number vector that stores latitude and longitude
INumberVectorProperty LocationNP;
INumber LocationN[3];
diff --git a/libs/indibase/indiweatherinterface.h b/libs/indibase/indiweatherinterface.h
index c3b3688d72..5d952abb37 100644
--- a/libs/indibase/indiweatherinterface.h
+++ b/libs/indibase/indiweatherinterface.h
@@ -63,7 +63,7 @@ class WeatherInterface
virtual ~WeatherInterface();
/**
- * \brief Initilize focuser properties. It is recommended to call this function within
+ * \brief Initialize focuser properties. It is recommended to call this function within
* initProperties() of your primary device
* \param statusGroup group for status properties
* \param paramsGroup group for parameter properties
@@ -114,7 +114,7 @@ class WeatherInterface
* - Alert: Any value outsize of Ok and Warning zone is marked as Alert.
*
* @param name Name of parameter
- * @param label Label of paremeter (in GUI)
+ * @param label Label of parameter (in GUI)
* @param numMinOk minimum Ok range value.
* @param numMaxOk maximum Ok range value.
* @param percWarning percentage for Warning.
diff --git a/libs/indibase/stream/ccvt.h b/libs/indibase/stream/ccvt.h
index 299465f0ab..30488164dc 100644
--- a/libs/indibase/stream/ccvt.h
+++ b/libs/indibase/stream/ccvt.h
@@ -23,7 +23,7 @@
/*
$Log$
Revision 1.4 2005/04/29 16:51:20 mutlaqja
- Adding initial support for Video 4 Linux 2 drivers. This mean that KStars can probably control Meade Lunar Planetary Imager (LPI). V4L2 requires a fairly recent kernel (> 2.6.9) and many drivers don't fully support it yet. It will take sometime. KStars still supports V4L1 and will continue so until V4L1 is obselete. Please test KStars video drivers if you can. Any comments welcomed.
+ Adding initial support for Video 4 Linux 2 drivers. This mean that KStars can probably control Meade Lunar Planetary Imager (LPI). V4L2 requires a fairly recent kernel (> 2.6.9) and many drivers don't fully support it yet. It will take sometime. KStars still supports V4L1 and will continue so until V4L1 is obsolete. Please test KStars video drivers if you can. Any comments welcomed.
CCMAIL: kstars-devel@kde.org
diff --git a/libs/indibase/stream/ccvt_misc.c b/libs/indibase/stream/ccvt_misc.c
index 2ca54771b4..18fcb805a8 100644
--- a/libs/indibase/stream/ccvt_misc.c
+++ b/libs/indibase/stream/ccvt_misc.c
@@ -27,7 +27,7 @@
/*
* $Log$
* Revision 1.2 2005/04/29 16:51:20 mutlaqja
- * Adding initial support for Video 4 Linux 2 drivers. This mean that KStars can probably control Meade Lunar Planetary Imager (LPI). V4L2 requires a fairly recent kernel (> 2.6.9) and many drivers don't fully support it yet. It will take sometime. KStars still supports V4L1 and will continue so until V4L1 is obselete. Please test KStars video drivers if you can. Any comments welcomed.
+ * Adding initial support for Video 4 Linux 2 drivers. This mean that KStars can probably control Meade Lunar Planetary Imager (LPI). V4L2 requires a fairly recent kernel (> 2.6.9) and many drivers don't fully support it yet. It will take sometime. KStars still supports V4L1 and will continue so until V4L1 is obsolete. Please test KStars video drivers if you can. Any comments welcomed.
*
* CCMAIL: kstars-devel@kde.org
*
diff --git a/libs/indibase/stream/jpegutils.c b/libs/indibase/stream/jpegutils.c
index 58ce58433c..d5055a84f4 100644
--- a/libs/indibase/stream/jpegutils.c
+++ b/libs/indibase/stream/jpegutils.c
@@ -76,7 +76,7 @@ static void init_source(j_decompress_ptr cinfo)
/*
* Fill the input buffer --- called whenever buffer is emptied.
*
- * Should never be called since all data should be allready provided.
+ * Should never be called since all data should be already provided.
* Is nevertheless sometimes called - sets the input buffer to data
* which is the JPEG EOI marker;
*
@@ -150,7 +150,7 @@ static void jpeg_buffer_src(j_decompress_ptr cinfo, unsigned char *buffer, long
/*
* jpeg_skip_ff is not a part of the source manager but it is
* particularly useful when reading several images from the same buffer:
- * It should be called to skip padding 0xff bytes beetween images.
+ * It should be called to skip padding 0xff bytes between images.
*/
static void jpeg_skip_ff(j_decompress_ptr cinfo)
diff --git a/libs/indibase/stream/jpegutils.h b/libs/indibase/stream/jpegutils.h
index de606e4c64..9cf8d7e787 100644
--- a/libs/indibase/stream/jpegutils.h
+++ b/libs/indibase/stream/jpegutils.h
@@ -67,7 +67,7 @@ int decode_jpeg_raw(unsigned char *jpeg_data, int len, int itype, int ctype, uns
* @param naxis 1 for mono, 3 for color
* @param w width of image in pixels
* @param h height image in pixels
- * @return 0 if decoding sucseeds, -1 otherwise.
+ * @return 0 if decoding succeeds, -1 otherwise.
*/
int decode_jpeg_rgb(unsigned char *inBuffer, unsigned long inSize, uint8_t **memptr, size_t *memsize, int *naxis, int *w,
int *h);
diff --git a/libs/indibase/stream/recorder/serrecorder.cpp b/libs/indibase/stream/recorder/serrecorder.cpp
index ba5e295266..99e3203d91 100644
--- a/libs/indibase/stream/recorder/serrecorder.cpp
+++ b/libs/indibase/stream/recorder/serrecorder.cpp
@@ -384,7 +384,7 @@ void SER_Recorder::dateTo64BitTS(int32_t year, int32_t month, int32_t day, int32
case 11: // Novenber
ts += (30 * m_septaseconds_per_day);
break;
- case 2: // Feburary
+ case 2: // February
if (is_leap_year(year))
{
ts += (29 * m_septaseconds_per_day);
diff --git a/libs/indibase/stream/recorder/theorarecorder.cpp b/libs/indibase/stream/recorder/theorarecorder.cpp
index c4b22f39ae..8cdeb5dd81 100644
--- a/libs/indibase/stream/recorder/theorarecorder.cpp
+++ b/libs/indibase/stream/recorder/theorarecorder.cpp
@@ -271,7 +271,7 @@ bool TheoraRecorder::open(const char *filename, char *errmsg)
We make this call just to set the encoder into 2-pass mode, because
by default enabling two-pass sets the buffer delay to the whole file
(because there's no way to explicitly request that behavior).
- If we waited until we were actually encoding, it would overwite our
+ If we waited until we were actually encoding, it would overwrite our
settings.*/
if(th_encode_ctl(td, TH_ENCCTL_2PASS_IN, nullptr, 0) < 0)
{
diff --git a/libs/indibase/stream/streammanager.cpp b/libs/indibase/stream/streammanager.cpp
index ec28f1598c..16a1a45c94 100644
--- a/libs/indibase/stream/streammanager.cpp
+++ b/libs/indibase/stream/streammanager.cpp
@@ -1037,7 +1037,7 @@ bool StreamManagerPrivate::setStream(bool enable)
else
LOGF_INFO("Starting the video stream with target FPS %.f", StreamOptionsN[OPTION_TARGET_FPS].value);
#endif
- LOGF_INFO("Starting the video stream with target exposure %.6f s (Max theoritical FPS %.f)",
+ LOGF_INFO("Starting the video stream with target exposure %.6f s (Max theoretical FPS %.f)",
StreamExposureNP[0].getValue(), 1 / StreamExposureNP[0].getValue());
FPSAverage.reset();
diff --git a/libs/indibase/stream/streammanager_p.h b/libs/indibase/stream/streammanager_p.h
index a643790079..c12239d58f 100644
--- a/libs/indibase/stream/streammanager_p.h
+++ b/libs/indibase/stream/streammanager_p.h
@@ -208,7 +208,7 @@ class StreamManagerPrivate
INDI::PropertySwitch EncoderSP {2};
enum { ENCODER_RAW, ENCODER_MJPEG };
- // Recorder Selector. Static but should be implmeneted as a dynamic plugin interface
+ // Recorder Selector. Static but should be implemented as a dynamic plugin interface
INDI::PropertySwitch RecorderSP {2};
enum { RECORDER_RAW, RECORDER_OGV };
diff --git a/libs/indibase/webcam/pwc-ioctl.h b/libs/indibase/webcam/pwc-ioctl.h
index 75b6b8a3ea..f2bdbb85ed 100644
--- a/libs/indibase/webcam/pwc-ioctl.h
+++ b/libs/indibase/webcam/pwc-ioctl.h
@@ -164,7 +164,7 @@ struct pwc_mpt_angles
{
int absolute; /* write-only */
int pan; /* degrees * 100 */
- int tilt; /* degress * 100 */
+ int tilt; /* degrees * 100 */
};
/* Range of angles of the camera, both horizontally and vertically.
diff --git a/libs/indibase/webcam/v4l2_base.cpp b/libs/indibase/webcam/v4l2_base.cpp
index 48eb44427f..4685c2e01b 100644
--- a/libs/indibase/webcam/v4l2_base.cpp
+++ b/libs/indibase/webcam/v4l2_base.cpp
@@ -463,7 +463,7 @@ bool V4L2_Base::isLXmodCapable()
* verified against the buffer list. No processing is done actually, and
* the buffer is immediately requeued.
*
- * @param errmsg is the error messsage updated in case of error.
+ * @param errmsg is the error message updated in case of error.
* @return 0 if frame read is processed, or -1 with error message updated.
*/
int V4L2_Base::read_frame(char * errmsg)
@@ -713,7 +713,7 @@ int V4L2_Base::stop_capturing(char * errmsg)
break;
case IO_METHOD_MMAP:
- /* Kernel 3.11 problem with streamoff: vb2_is_busy(queue) remains true so we can not change anything without diconnecting */
+ /* Kernel 3.11 problem with streamoff: vb2_is_busy(queue) remains true so we can not change anything without disconnecting */
/* It seems that device should be closed/reopened to change any capture format settings. From V4L2 API Spec. (Data Negotiation) */
/* Switching the logical stream or returning into "panel mode" is possible by closing and reopening the device. */
/* Drivers may support a switch using VIDIOC_S_FMT. */
diff --git a/libs/indibase/webcam/v4l2_decode/v4l2_builtin_decoder.cpp b/libs/indibase/webcam/v4l2_decode/v4l2_builtin_decoder.cpp
index afa2e2c298..af41430e5a 100644
--- a/libs/indibase/webcam/v4l2_decode/v4l2_builtin_decoder.cpp
+++ b/libs/indibase/webcam/v4l2_decode/v4l2_builtin_decoder.cpp
@@ -27,11 +27,11 @@
modprobe v4l2loopback video_nr=8 card_label="Indi Loopback" exclusive_caps=0,0
gst-launch-0.10 -v videotestsrc ! 'video/x-raw-bayer, format=(string)bggr, width=640, height=480, framerate=(fraction)2/1' ! v4l2sink device=/dev/video8
- For Gray16 format I use gst-launch with a videotstsrc in GRAY16 format writing in a FIFO and a C program reding the FIFO into the v4l2loopback device
+ For Gray16 format I use gst-launch with a videotstsrc in GRAY16 format writing in a FIFO and a C program reading the FIFO into the v4l2loopback device
mkfifo /tmp/videopipe
gst-launch-1.0 -v videotestsrc ! video/x-raw,format=\(string\)GRAY16_LE,width=1024,height=576,framerate=\(fraction\)25/1 ! filesink location =/tmp/videopipe
./gray16_to_v4l2 /dev/video8 < /tmp/videopipe &
- The C program ./gray16_to_v4l2 is adpated from https://github.com/umlaeute/v4l2loopback/blob/master/examples/yuv4mpeg_to_v4l2.c :
+ The C program ./gray16_to_v4l2 is adapated from https://github.com/umlaeute/v4l2loopback/blob/master/examples/yuv4mpeg_to_v4l2.c :
process_header/read_header calls are suppressed (copy_frames uses a while (true) loop), frame_width and frame_height are constant
and V4L2 pixel format is set to V4L2_PIX_FMT_Y16.
diff --git a/libs/indiclient/baseclient.cpp b/libs/indiclient/baseclient.cpp
index 640014e2b1..3d726aebdd 100644
--- a/libs/indiclient/baseclient.cpp
+++ b/libs/indiclient/baseclient.cpp
@@ -254,7 +254,7 @@ BaseClientPrivate::BaseClientPrivate(BaseClient *parent)
if (err_code < 0)
{
- // Silenty ignore property duplication errors
+ // Silently ignore property duplication errors
if (err_code != INDI_PROPERTY_DUPLICATED)
{
IDLog("Dispatch command error(%d): %s\n", err_code, msg);
diff --git a/libs/indiclient/baseclient.h b/libs/indiclient/baseclient.h
index 5565ce3bfc..18bd7f26db 100644
--- a/libs/indiclient/baseclient.h
+++ b/libs/indiclient/baseclient.h
@@ -59,7 +59,7 @@ class INDI::BaseClient : public INDI::AbstractBaseClient
public:
/** @brief Connect to INDI server.
* @returns True if the connection is successful, false otherwise.
- * @note This function blocks until connection is either successull or unsuccessful.
+ * @note This function blocks until connection is either successfull or unsuccessful.
*/
bool connectServer() override;
diff --git a/libs/indiclientqt/baseclientqt.cpp b/libs/indiclientqt/baseclientqt.cpp
index fa4df17479..bfe459487a 100644
--- a/libs/indiclientqt/baseclientqt.cpp
+++ b/libs/indiclientqt/baseclientqt.cpp
@@ -70,7 +70,7 @@ void BaseClientQtPrivate::listenINDI()
if (err_code < 0)
{
- // Silenty ignore property duplication errors
+ // Silently ignore property duplication errors
if (err_code != INDI_PROPERTY_DUPLICATED)
{
IDLog("Dispatch command error(%d): %s\n", err_code, msg);
diff --git a/libs/indiclientqt/baseclientqt.h b/libs/indiclientqt/baseclientqt.h
index 56650365e2..2263bf7185 100644
--- a/libs/indiclientqt/baseclientqt.h
+++ b/libs/indiclientqt/baseclientqt.h
@@ -56,7 +56,7 @@ class INDI::BaseClientQt : public QObject, public INDI::AbstractBaseClient
public:
/** @brief Connect to INDI server.
* @returns True if the connection is successful, false otherwise.
- * @note This function blocks until connection is either successull or unsuccessful.
+ * @note This function blocks until connection is either successfull or unsuccessful.
*/
bool connectServer() override;
diff --git a/libs/indicore/base64.h b/libs/indicore/base64.h
index d376b6a3b3..84b32a46a2 100644
--- a/libs/indicore/base64.h
+++ b/libs/indicore/base64.h
@@ -51,7 +51,7 @@ extern int to64frombits(unsigned char *out, const unsigned char *in, int inlen);
/** \brief Convert base64 to bytes array.
\param out output buffer in bytes. The buffer size must be at least (3 * size_of_in_buffer / 4) bytes long.
\param in input base64 buffer
- \param inlen base64 buffer lenght
+ \param inlen base64 buffer length
\return 0 on success, -1 on failure.
*/
diff --git a/libs/indicore/indiapi.h.in b/libs/indicore/indiapi.h.in
index 708fd89591..edfe9b3e5c 100644
--- a/libs/indicore/indiapi.h.in
+++ b/libs/indicore/indiapi.h.in
@@ -35,10 +35,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110 - 1301 USA
A full description of the INDI protocol is detailed in the INDI white paper
Under INDI, any number of clients can connect to any number of drivers running one or more devices. It is a true N-to-N server/client architecture topology
-allowing for reliable deployments of several INDI server, client, and driver instances distrubted across different systems in different physical and logical locations.
+allowing for reliable deployments of several INDI server, client, and driver instances distributed across different systems in different physical and logical locations.
The basic premise of INDI is this: Drivers are responsible for defining their functionality in terms of Properties. Clients are not aware of such properties until they establish connection with the driver
-and start receiving streams of defined properties. Each property encompases some functionality or information about the device. These include number, text, switch, light, and BLOB properties.
+and start receiving streams of defined properties. Each property encompasses some functionality or information about the device. These include number, text, switch, light, and BLOB properties.
For example, all devices define the CONNECTION vector switch property, which is compromised of two switches:
@@ -59,7 +59,7 @@ INDI is intended for developers seeking to add support for their devices in INDI
\section Development Developing under INDI
-Please refere to the INDI Developers Manual for a complete guide on INDI's driver developemnt framework.
+Please refer to the INDI Developers Manual for a complete guide on INDI's driver development framework.
The INDI Library API is divided into the following main sections:
@@ -105,7 +105,7 @@ Simulators provide a great framework to test drivers and equipment alike. INDI L
The simulator snoops FWHM from the focuser simulator which affects the generated images focus. All images are generated in standard FITS format.
- @ref GuideSim "Guide Simulator": Simple dedicated Guide Simulator.
- @ref FilterSim "Filter Wheel Simulator": Offers a simple simulator to change filter wheels and their corresponding designations.
-- @ref FocusSim "Focuser Simulator": Offers a simple simualtor for an absolute position focuser. It generates a simulated FWHM value that may be used by other simulator such as the CCD simulator.
+- @ref FocusSim "Focuser Simulator": Offers a simple simulator for an absolute position focuser. It generates a simulated FWHM value that may be used by other simulator such as the CCD simulator.
- @ref DomeSim "Dome Simulator": Offers a simple simulator for an absolute position dome with shutter.
- @ref GPSSimulator "GPS Simulator": Offers a simple simulator for GPS devices that send time and location data to the client and other drivers.
@@ -128,7 +128,7 @@ For a full list of contributors, please check
- * - IDDefXXX: use @ref INDI::DefaultDevice "INDI Default Device" defXXX functions intead.
+ * - IDDefXXX: use @ref INDI::DefaultDevice "INDI Default Device" defXXX functions instead.
*
*
* - IExxx functions to implement the event driven model.
@@ -294,7 +294,7 @@ extern void IDSnoopBLOBs(const char *snooped_device, const char *snooped_propert
/* @{ */
-/* signature of a callback, timout caller and work procedure function */
+/* signature of a callback, timeout caller and work procedure function */
/** @typedef IE_CBF
* @brief Signature of a callback.
@@ -512,7 +512,7 @@ extern int IUFindOnSwitchIndex(const ISwitchVectorProperty *sp);
/** @brief Returns the name of the first ON switch it finds in the supplied arguments.
* @note This is only valid for ISR_1OFMANY mode. That is, when only one switch out of many is allowed to be ON. Do not use this function if you can have multiple ON switches in the same vector property.
- * @note This is a convience function intended to be used in ISNewSwitch(...) function to find out ON switch name without having to change actual switch state via IUUpdateSwitch(..)
+ * @note This is a convenience function intended to be used in ISNewSwitch(...) function to find out ON switch name without having to change actual switch state via IUUpdateSwitch(..)
* @param states list of switch states passed by ISNewSwitch()
* @param names list of switch names passed by ISNewSwitch()
* @param n number of switches passed by ISNewSwitch()
diff --git a/libs/indicore/lilxml.cpp b/libs/indicore/lilxml.cpp
index ec59fb4b90..6703131ea6 100644
--- a/libs/indicore/lilxml.cpp
+++ b/libs/indicore/lilxml.cpp
@@ -39,7 +39,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110 - 1301 USA
#if defined(_MSC_VER)
#define snprintf _snprintf
#pragma warning(push)
-///@todo Introduce plattform indipendent safe functions as macros to fix this
+///@todo Introduce platform independent safe functions as macros to fix this
#pragma warning(disable : 4996)
#endif
@@ -98,7 +98,7 @@ struct LilXML_
String endtag; /* to check for match with opening tag*/
String entity; /* collect entity seq */
int delim; /* attribute value delimiter */
- int lastc; /* last char (just used wiht skipping)*/
+ int lastc; /* last char (just used with skipping)*/
int skipping; /* in comment or declaration */
int inblob; /* in oneBLOB element */
};
@@ -377,7 +377,7 @@ XMLEle **parseXMLChunk(LilXML *lp, char *buf, int size, char ynot[])
}
/* process one more character of an XML file.
- * when find closure with outter element return root of complete tree.
+ * when find closure with outer element return root of complete tree.
* when find error return NULL with reason in ynot[].
* when need more return NULL with ynot[0] = '\0'.
* N.B. it is up to the caller to delete any tree returned with delXMLEle().
@@ -1173,7 +1173,7 @@ static int oneXMLchar(LilXML *lp, int c, char ynot[])
case ENTINATTRV: /* working on entity in attr valu */
if (c == ';')
{
- /* if find a recongized esp seq, add equiv char else raw seq */
+ /* if find a recognized esp seq, add equiv char else raw seq */
growString(&lp->entity, c);
if (decodeEntity(lp->entity.s, &c))
growString(&lp->ce->at[lp->ce->nat - 1]->valu, c);
diff --git a/libs/indicore/lilxml.h b/libs/indicore/lilxml.h
index af3d3b0df3..20173d1c76 100644
--- a/libs/indicore/lilxml.h
+++ b/libs/indicore/lilxml.h
@@ -28,7 +28,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110 - 1301 USA
It only handles elements, attributes and pcdata content. and ... > are silently ignored. pcdata is collected into one string, sans leading whitespace first line. \n
- The following is an example of a cannonical usage for the lilxml library. Initialize a lil xml context and read an XML file in a root element.
+ The following is an example of a canonical usage for the lilxml library. Initialize a lil xml context and read an XML file in a root element.
\code
@@ -110,7 +110,7 @@ extern XMLEle **parseXMLChunk(LilXML *lp, char *buf, int size, char errmsg[]);
/** \brief Process an XML one char at a time.
\param lp a pointer to a lilxml parser.
\param c one character to process.
- \param errmsg a buffer to store error messages if an error in parsing is encounterd.
+ \param errmsg a buffer to store error messages if an error in parsing is encountered.
\return When the function parses a complete valid XML element, it will return a pointer to the XML element. A NULL is returned when parsing the element is still in progress, or if a parsing error occurs. Check errmsg for errors if NULL is returned.
*/
extern XMLEle *readXMLEle(LilXML *lp, int c, char errmsg[]);
@@ -253,7 +253,7 @@ extern const char *findXMLAttValu(XMLEle *ep, const char *name);
/** \brief return a surface copy of a node.
Don't copy childs or cdata.
- \return a new independant node
+ \return a new independent node
*/
extern XMLEle *shallowCloneXMLEle(XMLEle * ele);
@@ -262,7 +262,7 @@ extern XMLEle *shallowCloneXMLEle(XMLEle * ele);
\param ele the original tree
\param replace function which can provide replacement. Return 1 & set replace for replacement. Optional
\param self additional value passed to replace function
- \return a new independant node
+ \return a new independent node
*/
extern XMLEle * cloneXMLEle(XMLEle * ep, int (*replace)(void * self, XMLEle * source, XMLEle * * replace), void * self);
diff --git a/libs/indidevice/basedevice.h b/libs/indidevice/basedevice.h
index 1fc0ec43b0..884a23a7c8 100644
--- a/libs/indidevice/basedevice.h
+++ b/libs/indidevice/basedevice.h
@@ -37,7 +37,7 @@
/** @class INDI::BaseDevice
* @brief Class to provide basic INDI device functionality.
*
- * INDI::BaseDevice is the base device for all INDI devices and contains a list of all properties defined by the device either explicity or via a skeleton file.
+ * INDI::BaseDevice is the base device for all INDI devices and contains a list of all properties defined by the device either explicitly or via a skeleton file.
* You don't need to subclass INDI::BaseDevice class directly, it is inheritied by INDI::DefaultDevice which takes care of building a standard INDI device. Moreover, INDI::BaseClient
* maintains a list of INDI::BaseDevice objects as they get defined from the INDI server, and those objects may be accessed to retrieve information on the object properties or message log.
*
@@ -112,12 +112,12 @@ class BaseDevice
*/
void registerProperty(const INDI::Property &property);
void registerProperty(const INDI::Property &property,
- INDI_PROPERTY_TYPE type); // backward compatiblity (PentaxCCD, PkTriggerCordCCD)
+ INDI_PROPERTY_TYPE type); // backward compatibility (PentaxCCD, PkTriggerCordCCD)
/** @brief Remove a property
* @param name name of property to be removed. Pass NULL to remove the whole device.
* @param errmsg buffer to store error message.
- * @return 0 if successul, -1 otherwise.
+ * @return 0 if successful, -1 otherwise.
*/
int removeProperty(const char *name, char *errmsg);
@@ -239,7 +239,7 @@ class BaseDevice
/** @brief getDriverInterface returns ORed values of @ref INDI::BaseDevice::DRIVER_INTERFACE "DRIVER_INTERFACE". It presents the device classes supported by the driver.
* @return driver device interface descriptor.
- * @note For example, to know if the driver supports CCD interface, check the retruned value:
+ * @note For example, to know if the driver supports CCD interface, check the returned value:
* @code{.cpp}
* if (device.getDriverInterface() & CCD_INTERFACE)
* cout << "We received a camera!" << endl;
diff --git a/libs/indidevice/basedevice_p.h b/libs/indidevice/basedevice_p.h
index 7c3e520751..d838a165d6 100644
--- a/libs/indidevice/basedevice_p.h
+++ b/libs/indidevice/basedevice_p.h
@@ -176,7 +176,7 @@ class BaseDevicePrivate
};
public:
- BaseDevice self {make_shared_weak(this)}; // backward compatibile (for operators as pointer)
+ BaseDevice self {make_shared_weak(this)}; // backward compatible (for operators as pointer)
std::string deviceName;
BaseDevice::Properties pAll;
std::map watchPropertyMap;
diff --git a/libs/indidevice/indibase.h b/libs/indidevice/indibase.h
index e19627471a..0b14e7457d 100644
--- a/libs/indidevice/indibase.h
+++ b/libs/indidevice/indibase.h
@@ -19,9 +19,9 @@
* and reduces code overhead.
*
*
- * - BaseClient: Base class for INDI clients. By subclassing BaseClient, client can easily connect to INDI server and handle device communication, command, and notifcation.
+ * - BaseClient: Base class for INDI clients. By subclassing BaseClient, client can easily connect to INDI server and handle device communication, command, and notification.
* - BaseClientQt: Qt5 based class for INDI clients. By subclassing BaseClientQt, client can easily connect to INDI server
- * and handle device communication, command, and notifcation.
+ * and handle device communication, command, and notification.
* - BaseMediator: Abstract class to provide interface for event notifications in INDI::BaseClient.
* - BaseDevice: Base class for all INDI virtual devices as handled and stored in INDI::BaseClient. It is also the parent for all drivers.
* - DefaultDevice: INDI::BaseDevice with extended functionality such as debug, simulation, and configuration support.
diff --git a/libs/indidevice/indistandardproperty.h b/libs/indidevice/indistandardproperty.h
index c4da76c585..611369e539 100644
--- a/libs/indidevice/indistandardproperty.h
+++ b/libs/indidevice/indistandardproperty.h
@@ -27,7 +27,7 @@ namespace INDI
/**
* @namespace INDI::SP
- @brief INDI Standard Properties are common properties standarized across drivers and clients alike.
+ @brief INDI Standard Properties are common properties standardized across drivers and clients alike.
INDI does not place any special semantics on property names (i.e. properties are just texts, numbers, or switches that represent no physical function). While GUI clients can construct graphical representation of properties in order to permit the user to operate the device, we run into situations where clients and drivers need to agree on the exact meaning of some fundamental properties.
What if some client need to be aware of the existence of some property in order to perform some function useful to the user? How can that client tie itself to such a property if the property can be arbitrary defined by drivers?
@@ -61,7 +61,7 @@ namespace SP
* standard properties in the INDI library driver repository.
*
* As a general rule of the thumb, the status of properties reflects the command execution result:
- * IPS_OKAY: Command excuted successfully.
+ * IPS_OKAY: Command executed successfully.
* IPS_BUSY: Command execution under progress.
* IPS_ALERT: Command execution failed.
*/
diff --git a/libs/inicpp.h b/libs/inicpp.h
index 55e1ccb851..07d46cc331 100644
--- a/libs/inicpp.h
+++ b/libs/inicpp.h
@@ -40,7 +40,7 @@ namespace ini
* @param str string to be trimmed in place */
inline void trim(std::string &str)
{
- // first erasing from end should be slighty more efficient
+ // first erasing from end should be slightly more efficient
// because erasing from start potentially moves all chars
// multiple indices towards the front.
@@ -538,7 +538,7 @@ namespace ini
~IniFileBase()
{}
- /** Sets the separator charactor for fields in the INI file.
+ /** Sets the separator character for fields in the INI file.
* @param sep separator character to be used. */
void setFieldSep(const char sep)
{
diff --git a/libs/json.h b/libs/json.h
index cffbd7dce9..4067678b67 100644
--- a/libs/json.h
+++ b/libs/json.h
@@ -6013,7 +6013,7 @@ struct wide_string_input_helper
}
};
-// Wraps another input apdater to convert wide character types into individual bytes.
+// Wraps another input adapter to convert wide character types into individual bytes.
template
class wide_string_input_adapter
{
@@ -10850,7 +10850,7 @@ class binary_reader
}
if (is_ndarray) // ndarray dimensional vector can only contain integers, and can not embed another array
{
- return sax->parse_error(chars_read, get_token_string(), parse_error::create(113, chars_read, exception_message(input_format, "ndarray dimentional vector is not allowed", "size"), nullptr));
+ return sax->parse_error(chars_read, get_token_string(), parse_error::create(113, chars_read, exception_message(input_format, "ndarray dimensional vector is not allowed", "size"), nullptr));
}
std::vector dim;
if (JSON_HEDLEY_UNLIKELY(!get_ubjson_ndarray_size(dim)))
diff --git a/libs/indibase/indidustcapinterface.h b/libs/indibase/indidustcapinterface.h
index 4b312e0bcf..a221f64006 100644
--- a/libs/indibase/indidustcapinterface.h
+++ b/libs/indibase/indidustcapinterface.h
@@ -27,7 +27,7 @@
* \class DustCapInterface
\brief Provides interface to implement remotely controlled dust cover
- \e IMPORTANT: initDustCapProperties() must be called before any other function to initilize the Dust Cap properties.
+ \e IMPORTANT: initDustCapProperties() must be called before any other function to initialize the Dust Cap properties.
\e IMPORTANT: processDustCapSwitch() must be called in your driver ISNewSwitch function.
\author Jasem Mutlaq
@@ -50,17 +50,17 @@ class DustCapInterface
/**
* @brief Park dust cap (close cover). Must be implemented by child.
- * @return If command completed immediatly, return IPS_OK. If command is in progress, return IPS_BUSY. If there is an error, return IPS_ALERT
+ * @return If command completed immediately, return IPS_OK. If command is in progress, return IPS_BUSY. If there is an error, return IPS_ALERT
*/
virtual IPState ParkCap();
/**
* @brief unPark dust cap (open cover). Must be implemented by child.
- * @return If command completed immediatly, return IPS_OK. If command is in progress, return IPS_BUSY. If there is an error, return IPS_ALERT
+ * @return If command completed immediately, return IPS_OK. If command is in progress, return IPS_BUSY. If there is an error, return IPS_ALERT
*/
virtual IPState UnParkCap();
/** \brief Initilize dust cap properties. It is recommended to call this function within initProperties() of your primary device
\param deviceName Name of the primary device
\param groupName Group or tab name to be used to define focuser properties.
*/
@@ -50,17 +50,17 @@ class DustCapInterface
*/
virtual IPState UnParkCap();
- /** \brief Initilize dust cap properties. It is recommended to call this function within initProperties() of your primary device
+ /** \brief Initialize dust cap properties. It is recommended to call this function within initProperties() of your primary device
\param deviceName Name of the primary device
\param groupName Group or tab name to be used to define focuser properties.
diff --git a/libs/indibase/indifilterinterface.h b/libs/indibase/indifilterinterface.h
index 9bb6e71381..2378311d5f 100644
--- a/libs/indibase/indifilterinterface.h
+++ b/libs/indibase/indifilterinterface.h
@@ -31,7 +31,7 @@
A filter wheel can be an independent device, or an embedded filter wheel within another device (e.g. CCD camera). Child class must implement all the
pure virtual functions and call SelectFilterDone(int) when selection of a new filter position is complete in the hardware.
- \e IMPORTANT: initFilterProperties() must be called before any other function to initilize the filter properties.
+ \e IMPORTANT: initFilterProperties() must be called before any other function to initialize the filter properties.
\e IMPORTANT: processFilterSlot() must be called in your driver's ISNewNumber() function. processFilterSlot() will call the driver's
SelectFilter() accordingly.
@@ -87,14 +87,14 @@ class FilterInterface
~FilterInterface();
/**
* \brief Initilize filter wheel properties. It is recommended to call this function within
* initProperties() of your primary device
* \param groupName Group or tab name to be used to define filter wheel properties.
*/
void initProperties(const char *groupName);
/**
- * @brief updateProperties Defines or Delete proprties based on default device connection status
+ * @brief updateProperties Defines or Delete properties based on default device connection status
* @return True if all is OK, false otherwise.
*/
bool updateProperties();
@@ -87,14 +87,14 @@ class FilterInterface
~FilterInterface();
/**
- * \brief Initilize filter wheel properties. It is recommended to call this function within
+ * \brief Initialize filter wheel properties. It is recommended to call this function within
* initProperties() of your primary device
* \param groupName Group or tab name to be used to define filter wheel properties.
diff --git a/libs/indibase/indilightboxinterface.h b/libs/indibase/indilightboxinterface.h
index ab68255e17..fd41c726fe 100644
--- a/libs/indibase/indilightboxinterface.h
+++ b/libs/indibase/indilightboxinterface.h
@@ -33,7 +33,7 @@
The child class is expected to call the following functions from the INDI frameworks standard functions:
- \e IMPORTANT: initLightBoxProperties() must be called before any other function to initilize the Light device properties.
+ \e IMPORTANT: initLightBoxProperties() must be called before any other function to initialize the Light device properties.
\e IMPORTANT: isGetLightBoxProperties() must be called in your driver ISGetProperties function
\e IMPORTANT: processLightBoxSwitch() must be called in your driver ISNewSwitch function.
\e IMPORTANT: processLightBoxNumber() must be called in your driver ISNewNumber function.
@@ -56,7 +56,7 @@ class LightBoxInterface
LightBoxInterface(DefaultDevice *device, bool isDimmable);
virtual ~LightBoxInterface();
/** \brief Initilize light box properties. It is recommended to call this function within initProperties() of your primary device
\param deviceName Name of the primary device
\param groupName Group or tab name to be used to define light box properties.
*/
@@ -82,14 +82,14 @@ class LightBoxInterface
bool snoopLightBox(XMLEle *root);
/**
- * @brief setBrightness Set light level. Must be impelemented in the child class, if supported.
+ * @brief setBrightness Set light level. Must be implemented in the child class, if supported.
* @param value level of light box
* @return True if successful, false otherwise.
*/
virtual bool SetLightBoxBrightness(uint16_t value);
/**
- * @brief EnableLightBox Turn on/off on a light box. Must be impelemented in the child class.
+ * @brief EnableLightBox Turn on/off on a light box. Must be implemented in the child class.
* @param enable If true, turn on the light, otherwise turn off the light.
* @return True if successful, false otherwise.
*/
@@ -56,7 +56,7 @@ class LightBoxInterface
LightBoxInterface(DefaultDevice *device, bool isDimmable);
virtual ~LightBoxInterface();
- /** \brief Initilize light box properties. It is recommended to call this function within initProperties() of your primary device
+ /** \brief Initialize light box properties. It is recommended to call this function within initProperties() of your primary device
\param deviceName Name of the primary device
\param groupName Group or tab name to be used to define light box properties.
diff --git a/libs/indibase/indirotatorinterface.h b/libs/indibase/indirotatorinterface.h
index 95aa17baee..4ac815c114 100644
--- a/libs/indibase/indirotatorinterface.h
+++ b/libs/indibase/indirotatorinterface.h
@@ -33,9 +33,9 @@ using RI = INDI::RotatorInterface;
pure virtual functions. Only absolute position Rotators are supported. Angle is ranged from 0 to 360 increasing clockwise when looking at the back
of the camera.
- \e IMPORTANT: initRotatorProperties() must be called before any other function to initilize the Rotator properties.
+ \e IMPORTANT: initRotatorProperties() must be called before any other function to initialize the Rotator properties.
- \e IMPORTANT: processRotatorNumber() must be called in your driver's ISNewNumber() function. Similary, processRotatorSwitch() must be called in ISNewSwitch()
+ \e IMPORTANT: processRotatorNumber() must be called in your driver's ISNewNumber() function. Similarly, processRotatorSwitch() must be called in ISNewSwitch()
\author Jasem Mutlaq
*/
@@ -121,7 +121,7 @@ class RotatorInterface
explicit RotatorInterface(DefaultDevice *defaultDevice);
/**
* \brief Initilize Rotator properties. It is recommended to call this function within
* initProperties() of your primary device
* \param groupName Group or tab name to be used to define Rotator properties.
*/
@@ -209,7 +209,7 @@ class RotatorInterface
ISwitch ReverseRotatorS[2];
ISwitchVectorProperty ReverseRotatorSP;
- // Backlash toogle
+ // Backlash toggle
ISwitchVectorProperty RotatorBacklashSP;
ISwitch RotatorBacklashS[2];
@@ -121,7 +121,7 @@ class RotatorInterface
explicit RotatorInterface(DefaultDevice *defaultDevice);
/**
- * \brief Initilize Rotator properties. It is recommended to call this function within
+ * \brief Initialize Rotator properties. It is recommended to call this function within
* initProperties() of your primary device
* \param groupName Group or tab name to be used to define Rotator properties.